@@ -112,7 +112,7 @@ if (molt && molt != 1) cell2.innerHTML += ' <b>x'+molt+'<\/b>';
 cell3.width = '40px';
 cell3.style.textAlign = 'right';
 cell3.innerHTML = punti_in_num(val);
-totale = Number(totale) + Number(val);
+totale = Math.round((Number(totale) + Number(val)) * 1000) / 1000;
 var txt_tot = punti_in_num(totale);
 if (tot_indef) {
 if (totale > 0)  txt_tot += ' + ?';
@@ -881,7 +881,7 @@ cognome_int = idcognome_int.innerHTML;
 if (idcognome_int.getAttribute('title') != null) cognome_int = idcognome_int.getAttribute('title');
 idcognome = idcognome_int.parentNode;
 cognome = idcognome.innerHTML;
-if (cognome.substr(cognome.length - 6) == ' -&gt;' || cognome.substr(0,6) == '&lt;- ') {
+if ((cognome.substr(cognome.length - 6) == ' -&gt;' && direz != 'sx') || (cognome.substr(0,6) == '&lt;- ' && direz == 'sx')) {
 caselle[cas_agg].colSpan = caselle[cas_agg].colSpan + 2;
 idapp = arr_app[righe[n1].id.substr(3)];
 if (ApIF[idapp]) freccia = 0;
@@ -891,7 +891,7 @@ if (idcognome_int.innerHTML != cognome_int) idcognome_int.setAttribute('title',c
 else idcognome_int.removeAttribute('title');
 if (ApIF[idapp]) {
 tab_pren = caselle[cas_agg].getElementsByTagName('table');
-if (cognome.substr(0,6) == '&lt;- ') {
+if (cognome.substr(0,6) == '&lt;- ' && direz == 'sx') {
 idcognome.innerHTML = idcognome.innerHTML.substr(6);
 if (tab_pren.length) {
 tab_pren[0].style.borderTopLeftRadius = null;
@@ -907,6 +907,7 @@ tab_pren[0].style.borderBottomRightRadius = null;
 }
 }
 if (!riduci_font && idcognome.tagName == 'SMALL') idcognome.parentNode.parentNode.innerHTML = idcognome.innerHTML;
+// If reservation doesn't have an arrow in current direction don't add a new cell (continue to next in loop)
 continue;
 }
 }
@@ -979,7 +980,6 @@ caselle[n2].className = 'rd_'+(n2 - 1);
 if (gjs == '16' && direz == 'dx') {
 if (caselle[n2].style.backgroundColor == colore1) caselle[n2].style.backgroundColor = colore_date_altre;
 else caselle[n2].style.backgroundColor = colore_date_norm;
-
 }
 if (gjs == '14' && direz == 'sx') {
 if (caselle[n2].style.backgroundColor == colore1) caselle[n2].style.backgroundColor = colore_date_norm;
