@@ -279,6 +279,7 @@ dump_tabella("costi$anno_reg",$file);
 } # fine for $num1
 fwrite($file,"</database>
 ");
+echo "<br>";
 
 if ($includi_modelli == "SI") {
 include("./includes/templates/funzioni_modelli.php");
@@ -290,27 +291,27 @@ while ($ini_lingua = readdir($lang_dir)) {
 if ($ini_lingua != "." && $ini_lingua != "..") {
 $nome_file = mex2("mdl_disponibilita","crea_modelli.php",$ini_lingua).".php";
 if (@is_file("$percorso_cartella_modello/$nome_file")) dump_modello($nome_file,$percorso_cartella_modello,$file);
-} # fine if ($file != "." && $file != "..")
-} # fine while ($file = readdir($lang_dir))
+} # fine if ($ini_lingua != "." && $ini_lingua != "..")
+} # fine while ($ini_lingua = readdir($lang_dir))
 closedir($lang_dir);
 $templates_dir = opendir("./includes/templates/");
 while ($modello_ext = readdir($templates_dir)) {
 if ($modello_ext != "." && $modello_ext != ".." and @is_dir("./includes/templates/$modello_ext")) {
 include("./includes/templates/$modello_ext/name.php");
-if ($template_file_name["ita"]) $nome_file = $template_file_name["ita"];
-else $nome_file = "ita_".$template_file_name["en"];
+if ($template_file_name['ita']) $nome_file = $template_file_name['ita'];
+else $nome_file = "ita_".$template_file_name['en'];
 if (@is_file("$percorso_cartella_modello/$nome_file")) dump_modello($nome_file,$percorso_cartella_modello,$file);
 $lang_dir = opendir("./includes/lang/");
 while ($ini_lingua = readdir($lang_dir)) {
 if ($ini_lingua != "." && $ini_lingua != "..") {
 if ($template_file_name[$ini_lingua]) $nome_file = $template_file_name[$ini_lingua];
-else $nome_file = $ini_lingua."_".$template_file_name["en"];
+else $nome_file = $ini_lingua."_".$template_file_name['en'];
 if (@is_file("$percorso_cartella_modello/$nome_file")) dump_modello($nome_file,$percorso_cartella_modello,$file);
-} # fine if ($file != "." && $file != "..")
-} # fine while ($file = readdir($lang_dir))
+} # fine if ($ini_lingua != "." && $ini_lingua != "..")
+} # fine while ($ini_lingua = readdir($lang_dir))
 closedir($lang_dir);
 } # fine if ($modello_ext != "." and $modello_ext != ".." and...
-} # fine while ($file = readdir($lang_dig))
+} # fine while ($modello_ext = readdir($templates_dir))
 closedir($templates_dir);
 } # fine for $num_cart
 } # fine if ($includi_modelli == "SI")
@@ -354,6 +355,7 @@ fwrite($file,"<?php exit(); ?>
 fwrite($file,"<database>
 ");
 dump_tabella("contratti",$file);
+echo "<br>";
 fwrite($file,"</database>
 </backup>");
 flock($file,3);
