@@ -246,6 +246,7 @@ esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersona
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('selezione_tab_tutte_prenota','1','tutte')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('num_righe_tab_tutti_clienti','1','200')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('num_righe_tab_casse','1','50')");
+esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('tot_giornalero_tab_casse','1','gior,mens,tab')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('num_righe_tab_messaggi','1','80')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('num_righe_tab_doc_salvati','1','100')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('num_righe_tab_storia_soldi','1','200')");
@@ -262,6 +263,9 @@ esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersona
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('ultime_sel_ins_prezzi','1','')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('subordinazione','1','NO')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('percorso_cartella_modello','1','".C_DATI_PATH."')");
+esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('gest_cvc','1','NO')");
+esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('ordine_inventario','1','alf')");
+esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('tasti_pos','1','x2;x10;s;+1;+2;+3;+4;+5;+6;+7;+8;+9;s;-1')");
 if (defined("C_CARTELLA_CREA_MODELLI") and C_CARTELLA_CREA_MODELLI != "") {
 $c_cartella_crea_mod = C_CARTELLA_CREA_MODELLI;
 if (substr($c_cartella_crea_mod,-1) == "/") $c_cartella_crea_mod = substr($c_cartella_crea_mod,0,-1);
@@ -435,7 +439,7 @@ fclose($fileaperto);
 include("./includes/funzioni_relutenti.php");
 aggiorna_relutenti("","SI","","",$id_utente,$id_utente,"","","","","","","","nazione","nazioni",$tablenazioni,$tablerelutenti);
 aggiorna_relutenti("","SI","","",$id_utente,$id_utente,"","","","","","","","regione","regioni",$tableregioni,$tablerelutenti,"nazione","nazioni",$tablenazioni);
-#aggiorna_relutenti("","SI","","",$id_utente,$id_utente,"","","","","","","","citta","citta",$tablecitta,$tablerelutenti,"regione","regioni",$tableregioni);
+if (C_CREADB_CITTA_DEFAULT == "SI") aggiorna_relutenti("","SI","","",$id_utente,$id_utente,"","","","","","","","citta","citta",$tablecitta,$tablerelutenti,"regione","regioni",$tableregioni);
 aggiorna_relutenti("","SI","","",$id_utente,$id_utente,"","","","","","","","documentoid","documentiid",$tabledocumentiid,$tablerelutenti);
 aggiorna_relutenti("","SI","","",$id_utente,$id_utente,"","","","","","","","parentela","parentele",$tableparentele,$tablerelutenti);
 
@@ -786,7 +790,7 @@ echo "<option value=\"NO\"$selected>".mex2("No",$pag,$lingua)."</option>
 ".mex2("Nome del computer a cui collegarsi",$pag,$lingua).":
 <input type=\"text\" name=\"host_phprdb\" value=\"".C_CREADB_HOST."\"><br>
 ".mex2("Numero della porta a cui collegarsi",$pag,$lingua).": 
-<input type=\"text\" name=\"port_phprdb\" value=\"".C_CREADB_PORT."\">(".mex2("Normalmete 5432 o 5433 per Postgresql o 3306 per Mysql",$pag,$lingua).")<br>
+<input type=\"text\" name=\"port_phprdb\" value=\"".C_CREADB_PORT."\" size=\"7\">(".mex2("Normalmete 5432 o 5433 per Postgresql o 3306 per Mysql",$pag,$lingua).")<br>
 ".mex2("Nome per l'autenticazione al database",$pag,$lingua).": 
 <input type=\"text\" name=\"user_phprdb\" value=\"".C_CREADB_USER."\"><br>
 ".mex2("Parola segreta per l'autenticazione al database",$pag,$lingua).": 
@@ -812,11 +816,11 @@ echo "".mex2("Nome del database a cui collegarsi temporaneamente",$pag,$lingua).
 <option value=\"appartamenti\">".$trad_var['apartments']."</option>
 </select><br>
 ".mex2("Numero di unità da gestire",$pag,$lingua).": 
-<input type=\"text\" name=\"numappartamenti\"><br>
+<input type=\"text\" name=\"numappartamenti\" size=\"5\"><br>
 <div style=\"height: 6px\"></div>
-".mex2("Nome delle unità singole da gestire",$pag,$lingua).": ".$trad_var['beds']."<br>
+".mex2("Nome delle unità singole da gestire",$pag,$lingua).": <em>".$trad_var['beds']."</em> <small>(".mex2("non incluse nelle unità normali",$pag,$lingua).")</small><br>
 ".mex2("Numero di unità singole da gestire",$pag,$lingua).": 
-<input type=\"text\" name=\"numletti\" value=\"0\"><br>
+<input type=\"text\" name=\"numletti\" value=\"0\" size=\"5\"><br>
 <div style=\"text-align: center;\"><input class=\"sbutton\" type=\"submit\" name=\"creabase\" value=\"".mex2("Crea il database",$pag,$lingua)."\"></div><br>
 <input type=\"hidden\" name=\"lingua\" value=\"$lingua\">
 </div></form>";
