@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2013 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2014 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -228,7 +228,7 @@ $nuovo_id = risul_query($nuovo_id,0,0) + 1;
 $nomi_contr = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'nomi_contratti' and idutente = '1' ");
 $nomi_contr = risul_query($nomi_contr,0,'valpersonalizza');
 esegui_query("insert into $tableutenti (idutenti,nome_utente,tipo_pass,datainserimento,hostinserimento) values ('$nuovo_id','$nome','n','$datainserimento','$HOSTNAME')");
-esegui_query("insert into $tableprivilegi (idutente,anno,casse_consentite,priv_mod_pers,priv_ins_clienti,prefisso_clienti,priv_messaggi,priv_inventario) values ('$nuovo_id','1','n,','nnn','nnnss','n,','nn','nnnnnnnnn')");
+esegui_query("insert into $tableprivilegi (idutente,anno,casse_consentite,priv_mod_pers,priv_ins_clienti,prefisso_clienti,priv_messaggi,priv_inventario) values ('$nuovo_id','1','n,','nnnn','nnnss','n,','nn','nnnnnnnnn')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('col_tab_tutte_prenota','$nuovo_id','nu#@&cg#@&in#@&fi#@&tc#@&ca#@&pa#@&ap#@&pe#@&co')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('rig_tab_tutte_prenota','$nuovo_id','to#@&ta#@&ca#@&pc')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('dati_struttura','$nuovo_id','#@&#@&#@&#@&#@&#@&#@&#@&#@&#@&#@&')");
@@ -248,6 +248,7 @@ esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersona
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('num_righe_tab_tutti_clienti','$nuovo_id','200')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('num_righe_tab_messaggi','$nuovo_id','80')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('num_righe_tab_casse','$nuovo_id','50')");
+esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('tot_giornalero_tab_casse','$nuovo_id','gior,mens,tab')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('num_righe_tab_doc_salvati','$nuovo_id','100')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('num_righe_tab_storia_soldi','$nuovo_id','200')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('stile_data','$nuovo_id','europa')");
@@ -256,6 +257,8 @@ esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersona
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('origini_prenota','$nuovo_id','')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('attiva_checkin','$nuovo_id','NO')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('mostra_quadro_disp','$nuovo_id','')");
+esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('ordine_inventario','$nuovo_id','alf')");
+esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('tasti_pos','$nuovo_id','x2;x10;s;+1;+2;+3;+4;+5;+6;+7;+8;+9;s;-1')");
 $filelock = crea_lock_file(C_DATI_PATH."/lingua.php");
 include(C_DATI_PATH."/lingua.php");
 $file_lingua = @file(C_DATI_PATH."/lingua.php");
@@ -587,6 +590,31 @@ if ($id_utente_importa >= 2 and $id_utente_esporta >= 2 and $id_utente_importa !
 $utente_imp = esegui_query("select * from $tableutenti where idutenti = '$id_utente_importa' ");
 $utente_esp = esegui_query("select * from $tableutenti where idutenti = '$id_utente_esporta' ");
 if (numlin_query($utente_imp) == 1 and numlin_query($utente_esp) == 1) {
+
+if ($tipo_importa == "pers" or $tipo_importa == "priv_pers") {
+esegui_query("delete from $tablepersonalizza where idutente = '$id_utente_importa' and idpersonalizza NOT $LIKE 'giorno_vedi_ini_sett%' ");
+$pers = esegui_query("select * from $tablepersonalizza where idutente = '$id_utente_esporta' and idpersonalizza NOT $LIKE 'giorno_vedi_ini_sett%' ");
+$num_pers = numlin_query($pers);
+for ($num1 = 0 ; $num1 < $num_pers ; $num1++) {
+$e_idpersonalizza = aggslashdb(risul_query($pers,$num1,'idpersonalizza'));
+$e_valpersonalizza = aggslashdb(risul_query($pers,$num1,'valpersonalizza'));
+$e_valpersonalizza_num = aggslashdb(risul_query($pers,$num1,'valpersonalizza_num'));
+if (strcmp($e_valpersonalizza,"")) {
+$valpersonalizza = ",valpersonalizza";
+$e_valpersonalizza = ",'$e_valpersonalizza'";
+} # fine if (strcmp($e_valpersonalizza,""))
+else $valpersonalizza = "";
+if (strcmp($e_valpersonalizza_num,"")) {
+$valpersonalizza_num = ",valpersonalizza_num";
+$e_valpersonalizza_num = ",'$e_valpersonalizza_num'";
+} # fine if (strcmp($e_valpersonalizza_num,""))
+else $valpersonalizza_num = "";
+esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente$valpersonalizza$valpersonalizza_num) values ('$e_idpersonalizza','$id_utente_importa'$e_valpersonalizza$e_valpersonalizza_num) ");
+} # fine for $num1
+$pers_importate = "SI";
+} # fine if ($tipo_importa == "pers" or $tipo_importa == "priv_pers")
+
+if ($tipo_importa == "priv" or $tipo_importa == "priv_pers") {
 esegui_query("delete from $tableprivilegi where idutente = '$id_utente_importa' ");
 $priv = esegui_query("select * from $tableprivilegi where idutente = '$id_utente_esporta' ");
 $num_priv = numlin_query($priv);
@@ -625,10 +653,13 @@ esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersona
 } # fine if ($e_anno != 1)
 } # fine for $num1
 $priv_importati = "SI";
-} # fine if ($id_utente_importa >= 2 and...
+} # fine if ($tipo_importa == "priv" or $tipo_importa == "priv_pers")
+
 } # fine if (numlin_query($utente_imp) == 1 and numlin_query($utente_esp) == 1)
+} # fine if ($id_utente_importa >= 2 and...
 } # fine for $num_imp
 if ($priv_importati == "SI") echo "<b>".mex("Privilegi importati",$pag).".</b><br>";
+if ($pers_importate == "SI") echo "<b>".mex("Personalizzazioni importate",$pag).".</b><br>";
 unlock_tabelle($tabelle_lock);
 } # fine if ($importa_priv)
 
@@ -751,7 +782,12 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"gestione_utenti.ph
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"importa_priv\" value=\"SI\">
-".mex("Importa i privilegi",$pag)."
+".mex("Importa",$pag)."
+ <select name=\"tipo_importa\">
+<option value=\"priv_pers\"> ".mex("privilegi e personalizzazioni",$pag)."</option>
+<option value=\"priv\"> ".mex("solo i privilegi",$pag)."</option>
+<option value=\"pers\"> ".mex("solo le personalizzazioni",$pag)."</option>
+</select>
  <select name=\"id_utente_importa\">";
 echo str_replace("\">","\">".mex("dell'utente",$pag)." ",$option_select_utenti);
 $gruppi = esegui_query("select * from $tablegruppi order by idgruppi ");
