@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2012 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2014 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -44,6 +44,7 @@ define('C_CREADB_TEMPDB',"template1");
 define('C_CREADB_PREFISSO_TAB',"");
 # "NO", "SI" o "AUTO"
 define('C_UTILIZZA_SEMPRE_DEFAULTS',"NO");
+define('C_CREADB_CITTA_DEFAULT',"NO");
 
 
 
@@ -66,14 +67,15 @@ define('C_MASSIMO_NUM_UTENTI',40);
 define('C_MASSIMO_NUM_CLIENTI',70000);
 define('C_MASSIMO_NUM_TARIFFE',70);
 define('C_MASSIMO_NUM_CONTRATTI',70);
-define('C_MASSIMO_NUM_COSTI_AGG',150);
-define('C_MASSIMO_NUM_COSTI_AGG_IN_PRENOTA',50);
+define('C_MASSIMO_NUM_COSTI_AGG',250);
+define('C_MASSIMO_NUM_COSTI_AGG_IN_PRENOTA',60);
 define('C_MASSIMO_NUM_STORIA_SOLDI',90000);
 define('C_MASSIMO_NUM_COSTI',50000);
 define('C_MASSIMO_NUM_APP',0);
 define('C_MASSIMO_NUM_BYTE_UPLOAD',12582912);
 define('C_CREA_ULTIMO_ACCESSO',"SI");
 if (!defined('C_CARTELLA_CREA_MODELLI')) define('C_CARTELLA_CREA_MODELLI',"");
+define('C_DOMINIO_CREA_MODELLI',"");
 define('C_CHMOD_EXEC_MODELLI',"NO");
 define('C_CARTELLA_DOC',"");
 define('C_CARTELLA_FILES_REALI',"");
@@ -86,6 +88,7 @@ define('C_URL_LOGO',"");
 define('C_URL_FAVICON',"");
 define('C_SEC_LIMITE_LIBERA_APP',"");
 define('C_MASCHERA_EMAIL',"SI");
+define('C_LIB_MERCADOPAGO',"");
 define('C_URL_MODULO_PAYBOX',"http://");
 define('C_NASCONDI_MARCA',"");
 define('C_DISABILITA_COD_EMAIL_MODELLI',"NO");
