@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2014 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2015 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -53,8 +53,8 @@ $tablepersonalizza = $PHPR_TAB_PRE."personalizza";
 
 #@include("./includes/costanti.php");
 #@include(C_DATI_PATH."/costanti.php");
-define('C_PHPR_VERSIONE_NUM',2.10);
-define('C_PHPR_VERSIONE_TXT',"2.1.0");
+define('C_PHPR_VERSIONE_NUM',2.13);
+define('C_PHPR_VERSIONE_TXT',"2.1.3");
 
 # Se non si specifica nessun anno uso l'attuale
 $anno_corrente = date("Y",(time() + (C_DIFF_ORE * 3600)));
@@ -80,16 +80,16 @@ if (strstr($_SERVER['HTTP_USER_AGENT'],'(iP') or strstr($_SERVER['HTTP_USER_AGEN
 else $mobile_device = 0;
 
 
-if (function_exists("aggslashdb")) {
+if (function_exists('aggslashdb')) {
 $anno = aggslashdb($anno);
 $id_sessione = aggslashdb($id_sessione);
 $HOSTNAME = aggslashdb($HOSTNAME);
-} # fine if (function_exists("aggslashdb"))
+} # fine if (function_exists('aggslashdb'))
 else {
 $anno = addslashes($anno);
 $id_sessione = addslashes($id_sessione);
 $HOSTNAME = addslashes($HOSTNAME);
-} # fine else if (function_exists("aggslashdb"))
+} # fine else if (function_exists('aggslashdb'))
 
 
 
@@ -424,7 +424,10 @@ $limite_transazioni_vecchie = date("Y-m-d H:i:s",(time() - ($minuti_durata_sessi
 esegui_query("delete from $tabletransazioni where ultimo_accesso <= '$limite_transazioni_vecchie'");
 $login_sbagliati = esegui_query("select tipo_transazione from $tabletransazioni where tipo_transazione = 'err_l' and dati_transazione1 = '$nome_utente_phpr'");
 $login_sbagliati = numlin_query($login_sbagliati);
-if ($login_sbagliati >= $num_log_sbagliati) $messaggio_errore .= mex("Numero eccesivo di login <div style=\"display: inline; color: red;\">errati</div> negli ultimi","funzioni.php")." $minuti_durata_sessione ".mex("minuti","funzioni.php").".<br><br>";
+if ($login_sbagliati >= $num_log_sbagliati) {
+$messaggio_errore .= mex("Numero eccesivo di login <div style=\"display: inline; color: red;\">errati</div> negli ultimi","funzioni.php")." $minuti_durata_sessione ".mex("minuti","funzioni.php").".<br><br>";
+if (defined("C_HTML_POST_LOGIN") and C_HTML_POST_LOGIN != "") $messaggio_errore .= mex("È possibile reimpostare la password dal proprio account di hosting","funzioni.php").".".C_HTML_POST_LOGIN;
+} # fine if ($login_sbagliati >= $num_log_sbagliati)
 else {
 
 $utente = esegui_query("select * from $tableutenti where nome_utente = '$nome_utente_phpr'");
