@@ -65,7 +65,7 @@ return $id_prenota_prec;
 
 
 
-function cancella_prenotazione ($id_prenota,$cancella_pagato,$metodo_pagamento,$priv_mod_pagato,$lock,$anno,$PHPR_TAB_PRE,$id_utente,&$stato_canc,$metodo_pagamento_imp="") {
+function cancella_prenotazione ($id_prenota,$cancella_pagato,$metodo_pagamento,$priv_mod_pagato,$lock,$anno,$PHPR_TAB_PRE,$id_utente,&$stato_canc,$metodo_pagamento_imp="",$dettagli_prenota="") {
 $pag = "modifica_prenota.php";
 $tableprenota = $PHPR_TAB_PRE."prenota".$anno;
 $tableperiodi = $PHPR_TAB_PRE."periodi".$anno;
@@ -75,10 +75,12 @@ $tablepersonalizza = $PHPR_TAB_PRE."personalizza";
 $tablecostiprenota = $PHPR_TAB_PRE."costiprenota".$anno;
 $tablerclientiprenota = $PHPR_TAB_PRE."rclientiprenota".$anno;
 $tableinterconnessioni  = $PHPR_TAB_PRE."interconnessioni";
+$tableclienti = $PHPR_TAB_PRE."clienti";
 
 $continua_canc = "SI";
 $tabelle_lock = array($tableprenota,$tablecostiprenota,$tablerclientiprenota,$tablesoldi,$tableinterconnessioni);
-$altre_tab_lock = array($tableanni,$tableperiodi,$tablepersonalizza);
+if ($dettagli_prenota) $altre_tab_lock = array($tableanni,$tableperiodi,$tableclienti,$tablepersonalizza);
+else $altre_tab_lock = array($tableanni,$tableperiodi,$tablepersonalizza);
 $dati_prenota = esegui_query("select * from $tableprenota where idprenota = '$id_prenota' and idclienti != '0' ");
 $num_dati_prenota = numlin_query($dati_prenota);
 if ($num_dati_prenota == 0) {
@@ -128,7 +130,7 @@ $continua_canc = "NO";
 } # fine if ($num_dati_prenota == 0 and $continua_canc != "NO")
 
 if ($continua_canc != "NO") {
-$d_pagato = risul_query($dati_prenota,0,pagato);
+$d_pagato = risul_query($dati_prenota,0,'pagato');
 if ($d_pagato != 0) {
 if ($cancella_pagato and $priv_mod_pagato == "s") {
 if (get_magic_quotes_gpc()) $metodo_pagamento = (string) stripslashes($metodo_pagamento);
@@ -186,7 +188,24 @@ esegui_query("delete from $tableinterconnessioni where idlocale = '$id_prenota_s
 } # fine else if ($d_id_data_inizio == 0 and $id_prenota_prec)
 } # fine if ($id_prenota_succ)
 else esegui_query("delete from $tableinterconnessioni where idlocale = '$id_prenota' and tipoid = 'prenota' and anno = '$anno' ");
-$testo .= mex("Prenotazione",$pag)." $id_prenota ".mex("cancellata",$pag)."!<br>";
+if ($dettagli_prenota) {
+$cognome_cliente = risul_query($dati_prenota,0,'idclienti');
+$cognome_cliente = esegui_query("select cognome from $tableclienti where idclienti = '$cognome_cliente' ");
+$cognome_cliente = risul_query($cognome_cliente,0,'cognome');
+$data_inizio = risul_query($dati_prenota,0,'iddatainizio');
+$data_fine = risul_query($dati_prenota,0,'iddatafine');
+$data_inizio = esegui_query("select datainizio from $tableperiodi where idperiodi = '$data_inizio' ");
+$data_fine = esegui_query("select datafine from $tableperiodi where idperiodi = '$data_fine' ");
+if (numlin_query($data_inizio)) $data_inizio = risul_query($data_inizio,0,'datainizio');
+else $data_inizio = "";
+if (numlin_query($data_fine)) $data_fine = risul_query($data_fine,0,'datafine');
+else $data_fine = "";
+$stile_data = stile_data($id_utente);
+$data_inizio = formatta_data($data_inizio,$stile_data);
+$data_fine = formatta_data($data_fine,$stile_data);
+$testo .= mex("Prenotazione",$pag)." $id_prenota ".mex("a nome di",$pag)." <b>$cognome_cliente</b> ".mex("dal",$pag)." $data_inizio ".mex("al",$pag)." $data_fine <em>".mex("cancellata",$pag)."</em>!<br>";
+} # fine if ($dettagli_prenota)
+else $testo .= mex("Prenotazione",$pag)." $id_prenota ".mex("cancellata",$pag)."!<br>";
 } # fine if ($continua_canc != "NO")
 $stato_canc = $continua_canc;
 if ($tabelle_lock) unlock_tabelle($tabelle_lock);
@@ -447,10 +466,12 @@ if (!$d_num_persone) $d_num_persone = 0;
 $d_tariffesettimanali = risul_query($dati_prenota_modifica,0,'tariffesettimanali');
 $d_tariffesettimanali_idpr[$id_prenota] = $d_tariffesettimanali;
 $d_costo_agg_tot = (double) 0;
+$costo_escludi_perc = (double) 0;
 if ($dati_da_anno_prec == "SI") passa_var_a_anno_prec($id_prenota,$tableperiodi,$tableprenota,$tablecostiprenota,$d_id_data_inizio,$d_id_data_fine,$n_fineperiodo,$inizioperiodo,$fineperiodo,$lunghezza_periodo,$dati_prenota_modifica);
 for ($numca = 0 ; $numca < $dati_cap['num'] ; $numca++) {
-$d_prezzo_costo_agg[$numca] = (double) calcola_prezzo_totale_costo($dati_cap,$numca,$d_id_data_inizio,$d_id_data_fine,$dati_cap[$numca]['settimane'],$dati_cap[$numca]['moltiplica_costo'],$d_costo_tariffa,$d_tariffesettimanali,($d_costo_tariffa + $d_costo_agg_tot - $d_sconto),$d_caparra,$d_num_persone);
+$d_prezzo_costo_agg[$numca] = (double) calcola_prezzo_totale_costo($dati_cap,$numca,$d_id_data_inizio,$d_id_data_fine,$dati_cap[$numca]['settimane'],$dati_cap[$numca]['moltiplica_costo'],$d_costo_tariffa,$d_tariffesettimanali,($d_costo_tariffa + $d_costo_agg_tot - $d_sconto),$d_caparra,$d_num_persone,$costo_escludi_perc);
 $d_costo_agg_tot = (double) $d_costo_agg_tot + $d_prezzo_costo_agg[$numca];
+if ($dati_cap[$numca]['escludi_tot_perc'] == "s") $costo_escludi_perc = (double) $costo_escludi_perc + $d_prezzo_costo_agg[$numca];
 } # fine for $numca
 $d_costo_agg_tot_idpr[$id_prenota] = $d_costo_agg_tot;
 $d_prezzo_costo_agg_idpr[$id_prenota] = $d_prezzo_costo_agg;
@@ -478,8 +499,8 @@ $n_host_inserimento_idpr[$id_prenota] = risul_query($dati_prenota_modifica,0,'ho
 
 
 function esegui_modifiche_prenotazione (&$inserire,&$cancellata,$id_prenota_int,$id_prenota_idpr,$num_id_prenota,$id_transazione,$id_sessione,$anno,$id_nuovo_utente_inserimento,$n_stima_checkin,$n_met_paga_caparra,$n_origine_prenota,$n_pagato,$n_confermato,$tipo_commento,$n_commento,$n_cancella_commento,$tableprenota_da_aggiornare,$tipo_sposta,$dati_da_anno_prec,$prenota_in_anno_succ,$tra_anni,$PHPR_TAB_PRE) {
-global $id_utente,$priv_mod_checkin,$attiva_regole1_consentite,$regole1_consentite,$attiva_tariffe_consentite,$tariffe_consentite_vett,$priv_mod_date,$priv_ins_periodi_passati,$priv_mod_commento,$priv_mod_sconto,$priv_mod_caparra,$priv_mod_pagato,$priv_mod_orig_prenota,$d_commento,$cassa_pagamenti;
-global $dati_ca,$d_id_utente_inserimento_idpr,$d_appartamento_idpr,$d_id_data_inizio_idpr,$d_nome_tariffa_idpr,$d_app_eliminati_costi_idpr,$d_checkin_idpr,$d_checkout_idpr,$d_prenota_comp_idpr,$fineperiodo_orig;
+global $id_utente,$priv_mod_checkin,$attiva_regole1_consentite,$regole1_consentite,$attiva_tariffe_consentite,$tariffe_consentite_vett,$priv_mod_date,$priv_ins_periodi_passati,$priv_mod_commento,$priv_mod_commenti_pers,$priv_mod_sconto,$priv_mod_caparra,$priv_mod_pagato,$priv_mod_orig_prenota,$d_commento,$cassa_pagamenti;
+global $dati_ca,$d_id_utente_inserimento_idpr,$d_appartamento_idpr,$d_id_data_inizio_idpr,$d_nome_tariffa_idpr,$d_app_eliminati_costi_idpr,$d_checkin_idpr,$d_checkout_idpr,$d_prenota_comp_idpr,$fineperiodo_orig,$comm_pers_presenti;
 global $id_prenota_orig,$tableperiodi_orig,$tableprenota_orig,$tablecostiprenota_orig,$tableperiodi_prec,$tableprenota_prec,$tablecostiprenota_prec,$stile_data;
 
 $pag = "modifica_prenota.php";
@@ -754,7 +775,10 @@ if ($id_periodo_corrente >= $inizioperiodo) $inserire = "NO";
 #if ($n_numpersone != "" and $priv_mod_num_persone != "s") $inserire = "NO";
 if ($n_numpersone and controlla_num_pos ($n_numpersone) != "SI") $inserire = "NO";
 
-if ($priv_mod_commento != "s" and ($n_commento != "" or $n_cancella_commento)) $inserire = "NO";
+if ($priv_mod_commenti_pers != "s" and $tipo_commento != "checkin" and $tipo_commento != "checkout") $tipo_commento = "";
+if ($priv_mod_commento != "s" and !strcmp($tipo_commento,"")) $n_commento = "";
+if ($priv_mod_commento != "s" and ((strcmp($n_commento,"") and (!strcmp($tipo_commento,"") or $tipo_commento == "checkin" or $tipo_commento == "checkout")) or $n_cancella_commento)) $inserire = "NO";
+if ($priv_mod_commenti_pers == "s" and strcmp($tipo_commento,"") and !$comm_pers_presenti[$tipo_commento] and $tipo_commento != "checkin" and $tipo_commento != "checkout") $inserire = "NO";
 
 if (strcmp($n_sconto,"") and ($priv_mod_sconto != "s" or controlla_soldi($n_sconto) == "NO")) $inserire = "NO";
 
@@ -1175,6 +1199,7 @@ esegui_query("update $tableprenota set tariffesettimanali = '$n_tariffesettimana
 } # fine if ($n_tariffesettimanali != "")
 
 if ($costi_aggiuntivi_modificati_int) {
+$costi_aggiuntivi_modificati = explode("#@&",$costi_aggiuntivi_modificati_int);
 for ($num2 = 0 ; $num2 < count($costi_aggiuntivi_modificati) ; $num2++) {
 $costo_agg_modificato = explode("#?&",$costi_aggiuntivi_modificati[$num2]);
 if ($costo_agg_modificato[1] == "cancella") esegui_query("delete from $tablecostiprenota where idcostiprenota = '".$costo_agg_modificato[0]."' and idprenota = '$id_prenota' ");
@@ -1186,6 +1211,7 @@ if ($num_ripetizioni_costo_mod_idpr[$id_prenota][$num2]) esegui_query("update $t
 } # fine if ($costi_aggiuntivi_modificati_int)
 
 if ($costi_aggiuntivi_da_inserire_int) {
+$costi_aggiuntivi_da_inserire = explode("#@&",$costi_aggiuntivi_da_inserire_int);
 for ($num2 = 0 ; $num2 < count($costi_aggiuntivi_da_inserire) ; $num2++) {
 $costo_agg_da_inserire = explode("#?&",$costi_aggiuntivi_da_inserire[$num2]);
 $num_costo = $dati_ca['id'][$costo_agg_da_inserire[9]];
@@ -1262,12 +1288,13 @@ if ($n_confermato != "") {
 esegui_query("update $tableprenota set conferma = '$n_confermato' where idprenota = '$id_prenota' ");
 } # fine if ($n_confermato != "")
 
-if ($n_commento != "" and ($tipo_commento == "checkin" or $tipo_commento == "checkout")) {
+if (strcmp($n_commento,"") and ($tipo_commento == "checkin" or $tipo_commento == "checkout")) {
 $n_comm_checkin = "";
 $n_comm_checkout = "";
 if ($tipo_commento == "checkin" and !$d_checkin_idpr[$id_prenota]) $n_comm_checkin = $n_commento;
 if ($tipo_commento == "checkout" and !$d_checkout_idpr[$id_prenota]) $n_comm_checkout = $n_commento;
 $n_comm = $d_commento;
+$altri_comm = "";
 if (strstr($n_comm,">")) {
 $n_comm = explode(">",$n_comm);
 if (strcmp($n_comm[1],"")) {
@@ -1278,18 +1305,49 @@ if (strcmp($n_comm[2],"")) {
 if ($n_comm_checkout) $n_comm_checkout = $n_comm[2]." - $n_comm_checkout";
 else $n_comm_checkout = $n_comm[2];
 } # fine if (strcmp($n_comm[2],""))
+for ($num1 = 3 ; $num1 < count($n_comm) ; $num1++) {
+$altri_comm .= ">".$n_comm[$num1];
+} # fine for $num1
 $n_comm = $n_comm[0];
 } # fine if (strstr($n_comm,">"))
 if (strcmp($n_comm_checkin,"") or strcmp($n_comm_checkout,"")) $n_comm .= ">$n_comm_checkin>$n_comm_checkout";
+elseif ($altri_comm) $n_comm .= ">>";
+if ($altri_comm) $n_comm .= $altri_comm;
 esegui_query("update $tableprenota set commento = '".aggslashdb($n_comm)."' where idprenota = '$id_prenota' ");
-} # fine if ($n_commento != "" and ($tipo_commento == "checkin" or...
+} # fine if (strcmp($n_commento,"") and ($tipo_commento == "checkin" or...
 
-if (($n_commento != "" and $tipo_commento != "checkin" and $tipo_commento != "checkout") or $n_cancella_commento == "SI") {
+if ((strcmp($n_commento,"") and !strcmp($tipo_commento,"")) or $n_cancella_commento == "SI") {
 $n_comm = $n_commento;
 if ($n_cancella_commento == "SI") $n_comm = "";
 if (strstr($d_commento,">")) $n_comm = $n_comm.strstr($d_commento,">");
 esegui_query("update $tableprenota set commento = '".aggslashdb($n_comm)."' where idprenota = '$id_prenota' ");
-} # fine if (($n_commento != "" and $tipo_commento != "checkin" and $tipo_commento != "checkout") or...
+} # fine if ((strcmp($n_commento,"") and !strcmp($tipo_commento,"")) or $n_cancella_commento == "SI")
+
+if (strcmp($tipo_commento,"") and $comm_pers_presenti[$tipo_commento]) {
+$n_comm = $d_commento;
+if (strstr($d_commento,">")) {
+$d_comm = explode(">",$d_commento);
+$num_comm = count($d_comm);
+if ($num_comm < 4) {
+for ($num1 = $num_comm ; $num1 < 3 ; $num1++) $n_comm .= ">";
+$n_comm .= ">".$tipo_commento."<".$n_commento;
+} # fine if ($num_comm < 4)
+else {
+$n_comm = $d_comm[0].">".$d_comm[1].">".$d_comm[2];
+$n_comm_inserito = 0;
+for ($num1 = 3 ; $num1 < $num_comm ; $num1++) {
+if (substr($d_comm[$num1],0,(strlen($tipo_commento) + 1)) == "$tipo_commento<") {
+$n_comm_inserito = 1;
+if (strcmp($n_commento,"")) $n_comm .= ">".$tipo_commento."<".$n_commento;
+} # fine if (substr($d_comm[$num1],0,(strlen($tipo_commento) + 1)) == "$tipo_commento<")
+else $n_comm .= ">".$d_comm[$num1];
+} # fine for $num1
+if (!$n_comm_inserito and strcmp($n_commento,"")) $n_comm .= ">".$tipo_commento."<".$n_commento;
+} # fine else if ($num_comm < 4)
+} # fine if (strstr($d_commento,">"))
+elseif (strcmp($n_commento,"")) $n_comm .= ">>>".$tipo_commento."<".$n_commento;
+if ($n_comm != $d_commento) esegui_query("update $tableprenota set commento = '".aggslashdb($n_comm)."' where idprenota = '$id_prenota' ");
+} # fine if (strcmp($tipo_commento,"") and $comm_pers_presenti[$tipo_commento])
 
 $adesso = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
 esegui_query("update $tableprenota set tariffa_tot = '$n_costo_tot', data_modifica = '$adesso' where idprenota = '$id_prenota' ");
