@@ -85,7 +85,7 @@ case "Modifica come gruppo le prenotazioni inserite":	$messaggio = "Modify inser
 case "prezzo totale":  				$messaggio = "total price"; break;
 case "prezzo totale giornaliero":  		$messaggio = "daily total price"; break;
 case "prezzo totale settimanale":  		$messaggio = "weekly total price"; break;
-case "prezzo tarffa":  				$messaggio = "rate price"; break;
+case "prezzo tariffa":  			$messaggio = "rate price"; break;
 case "prezzo tariffa giornaliero":  		$messaggio = "daily rate price"; break;
 case "prezzo tariffa settimanale":  		$messaggio = "weekly rate price"; break;
 case "% del totale":  				$messaggio = "% of total"; break;
@@ -97,8 +97,8 @@ case "modificata":  				$messaggio = "modified"; break;
 case "Errore":  				$messaggio = "Error"; break;
 case "costo aggiuntivo":  			$messaggio = "extra cost"; break;
 case "per la prenotazione":  			$messaggio = "for reservation"; break;
-case "per l'entrata":  				$messaggio = "for checkin"; break;
-case "per l'uscita":  				$messaggio = "for checkout"; break;
+case "per un promemoria all'entrata":  		$messaggio = "for a reminder at checkin"; break;
+case "per un promemoria all'uscita":  		$messaggio = "for a reminder at checkout"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
