@@ -51,6 +51,8 @@ $trad_var['costo_tariffa_giorno_array'] = 'rate_price_of_array_day';
 $trad_var['costo_tariffa_giorno_array_p'] = 'rate_price_of_array_day_p';
 $trad_var['sconto'] = 'discount';
 $trad_var['commento'] = 'comment';
+$trad_var['promemoria_entrata'] = 'checkin_reminder';
+$trad_var['promemoria_uscita'] = 'checkout_reminder';
 $trad_var['origine_prenotazione'] = 'reservation_origin';
 $trad_var['unita_occupata'] = 'occupied_unit';
 $trad_var['unita_assegnabili'] = 'units_list';
@@ -258,6 +260,8 @@ $trad_var['codice_fiscale_struttura'] = 'structure_fiscal_code';
 $trad_var['partita_iva_struttura'] = 'structure_vat_number';
 $trad_var['numero_stelle_struttura'] = 'structure_stars_number';
 $trad_var['logo_struttura'] = 'structure_logo';
+$trad_var['testo_email_richiesta'] = 'enquiry_email_text';
+$trad_var['testo_quotato_email_richiesta'] = 'enquiry_email_quoted_text';
 $trad_var['nome_valuta'] = 'currency_name';
 $trad_var['ritorno_a_capo'] = 'carriage_return';
 $trad_var['avanzamento_riga'] = 'new_line';
@@ -265,6 +269,8 @@ $trad_var['errore_ripetizione'] = 'repetition_error';
 $trad_var['messaggio_di_errore'] = 'error_message';
 $trad_var['codice_lingua'] = 'language_code';
 $trad_var['email_gia_inviata'] = 'email_already_sent';
+$trad_var['commento_personalizzato'] = 'custom_comment';
+$trad_var['campo_personalizzato'] = 'custom_field';
 
 
 ?>
\ No newline at end of file
