@@ -85,7 +85,7 @@ case "Modifica come gruppo le prenotazioni inserite":	$messaggio = "Modifica com
 case "prezzo totale":  				$messaggio = "precio total"; break;
 case "prezzo totale giornaliero":  		$messaggio = "precio total diario"; break;
 case "prezzo totale settimanale":  		$messaggio = "precio total semanal"; break;
-case "prezzo tarffa":  				$messaggio = "precio tarifa"; break;
+case "prezzo tariffa":  			$messaggio = "precio tarifa"; break;
 case "prezzo tariffa giornaliero":  		$messaggio = "precio tarifa diario"; break;
 case "prezzo tariffa settimanale":  		$messaggio = "precio tarifa semanal"; break;
 case "% del totale":  				$messaggio = "% del total"; break;
@@ -97,8 +97,8 @@ case "modificata":  				$messaggio = "modificada"; break;
 case "Errore":  				$messaggio = "Error"; break;
 case "costo aggiuntivo":  			$messaggio = "coste añadido"; break;
 case "per la prenotazione":  			$messaggio = "para la reserva"; break;
-case "per l'entrata":  				$messaggio = "para la entrada"; break;
-case "per l'uscita":  				$messaggio = "para la salida"; break;
+case "per un promemoria all'entrata":  		$messaggio = "para un recordatorio a la entrada"; break;
+case "per un promemoria all'uscita":  		$messaggio = "para un recordatorio a la salida"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
