@@ -45,7 +45,7 @@ case "Data_di_inserimento":  			$messaggio = "Fecha_de_inserción"; break;
 case "Cancella":  				$messaggio = "Borrar"; break;
 case "Tutte le entrate del":  			$messaggio = "Todas las entradas del"; break;
 case "Natura_entrata":  			$messaggio = "Razón_de_la_entrada"; break;
-case "cancella":  				$messaggio = "borra"; break;
+case "cancella":  				$messaggio = "borrar"; break;
 case "entrata presa dalle prenotazioni":  	$messaggio = "entrada cogida de las reservas"; break;
 case "Inserisci nuove spese o entrate":  	$messaggio = "Insera nuevos gastos o entradas"; break;
 case "Storia entrate-uscite prenotazioni":  	$messaggio = "Historial de pagos de las reservas"; break;
@@ -210,7 +210,7 @@ case "OK":  					$messaggio = "OK"; break;
 case "Annulla":  				$messaggio = "Cancelar"; break;
 case "Si è sicuri di voler <div style=\"display: inline; color: red;\"><b>cancellare":	$messaggio = "Estas seguro de querer <div style=\"display: inline; color: red;\"><b>borrar"; break;
 case "clienti</b></div> che non sono associati a nessuna prenotazione e nessun pagamento":	$messaggio = "clientes</b></div> que no estan asociados a ninguna reserva y ningun pago"; break;
-case "carte di credito</b></div> associate a clienti che non hanno nessuna prenotazione nel futuro":	$messaggio = "tarjetas de crédito</b></div> asociadas a clientes que no tienen reservas en el futuro"; break;
+case "carte di credito</b></div> associate a clienti che non hanno nessuna prenotazione nel futuro e nessuna prenotazione non pagata":	$messaggio = "tarjetas de crédito</b></div> asociadas a clientes que no tienen reservas en el futuro y ninguna reserva no pagada"; break;
 case "Cancella i clienti senza prenotazioni":	$messaggio = "Borrar los clientes sin reservas"; break;
 case "Metodo pagamento":  			$messaggio = "Método pago"; break;
 case "Tariffe":  				$messaggio = "Tarifas"; break;
@@ -355,6 +355,9 @@ case "Creare":  				$messaggio = "Crear"; break;
 case "Aggiungi":  				$messaggio = "Añadir"; break;
 case "persona":  				$messaggio = "persona"; break;
 case "chiusa":  				$messaggio = "cerrada"; break;
+case "presenti in data":  			$messaggio = "presentes el"; break;
+case "comprese partenze":  			$messaggio = "incluyendo las salidas"; break;
+case "escludere_da_totale_percentuale":  	$messaggio = "excluir_del_total_para_porcentaje"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
