@@ -167,7 +167,7 @@ if (substr($$variabile,0,1) == "\"" and substr($$variabile,-1) == "\"") $$variab
 if (substr(str_replace(" ","",$$variabile),0,6) == "array(") {
 $vett = $$variabile;
 $$variabile = "";
-${$variabile}["array_esistente"] = "SI";
+${$variabile}['array_esistente'] = "SI";
 $vett = preg_replace("/^array[ ]*\(/","",$vett);
 if (substr($vett,-1) == ")") $vett = substr($vett,0,-1);
 if (strcmp(trim($vett),"")) {
@@ -809,7 +809,7 @@ if (defined("C_FILE_SCADENZA_ACCOUNT") and C_FILE_SCADENZA_ACCOUNT != "") {
 $f_scad_acc = explode("/",$percorso_cartella_modello);
 $num_f_scad_acc = count($f_scad_acc);
 $file_scad_acc = "";
-for ($num1 = 0 ; $num1 < $num_f_scad_acc ; $num1++) $file_scad_acc .= "../";
+for ($num1 = 0 ; $num1 < $num_f_scad_acc ; $num1++) if ($f_scad_acc[$num1] != ".") $file_scad_acc .= "../";
 $file_scad_acc .= C_FILE_SCADENZA_ACCOUNT;
 fwrite($file,"
 \$disattivato = \"\";
