@@ -755,7 +755,7 @@ if (defined("C_FILE_SCADENZA_ACCOUNT") and C_FILE_SCADENZA_ACCOUNT != "") {
 $f_scad_acc = explode("/",$percorso_cartella_modello);
 $num_f_scad_acc = count($f_scad_acc);
 $file_scad_acc = "";
-for ($num1 = 0 ; $num1 < $num_f_scad_acc ; $num1++) $file_scad_acc .= "../";
+for ($num1 = 0 ; $num1 < $num_f_scad_acc ; $num1++) if ($f_scad_acc[$num1] != ".") $file_scad_acc .= "../";
 $file_scad_acc .= C_FILE_SCADENZA_ACCOUNT;
 fwrite($file,"
 \$disattivato = \"\";
