@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2014 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2015 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -68,7 +68,7 @@ break;
 if (@is_file("./COPYING")) $file_copying = "file <a href=\"COPYING\">COPYING</a>";
 else $file_copying = "<a href=\"http://www.gnu.org/licenses/agpl-3.0.html\">AGPLv3</a> License";
 echo "<div style=\"text-align: center;\"><h3>".mex("Benvenuto a HOTELDRUID",$pag).".</h3><br><br>
-HOTELDRUID version ".C_PHPR_VERSIONE_TXT.", Copyright (C) 2001-2014 Marco M. F. De Santis<br>
+HOTELDRUID version ".C_PHPR_VERSIONE_TXT.", Copyright (C) 2001-2015 Marco M. F. De Santis<br>
 HotelDruid comes with ABSOLUTELY NO WARRANTY; <br>for details see the $file_copying.<br>
 This is free software, and you are welcome to redistribute it<br>
  under certain conditions; see the $file_copying for details.<br>
@@ -116,6 +116,7 @@ $privilegi_globali_utente = esegui_query("select * from $tableprivilegi where id
 $priv_mod_pers = risul_query($privilegi_globali_utente,0,'priv_mod_pers');
 if (substr($priv_mod_pers,0,1) != "s") $modifica_pers = "NO";
 $priv_crea_backup = substr($priv_mod_pers,1,1);
+$priv_crea_interconnessioni = substr($priv_mod_pers,3,1);
 $priv_ins_clienti = risul_query($privilegi_globali_utente,0,'priv_ins_clienti');
 if (substr($priv_ins_clienti,0,1) != "s") $inserimento_nuovi_clienti = "NO";
 if (substr($priv_ins_clienti,1,1) != "s" and substr($priv_ins_clienti,1,1) != "p" and substr($priv_ins_clienti,1,1) != "g") $modifica_clienti = "NO";
@@ -173,6 +174,7 @@ else {
 $anno_utente_attivato = "SI";
 $modifica_pers = "SI";
 $priv_crea_backup = "s";
+$priv_crea_interconnessioni = "s";
 $inserimento_nuovi_clienti = "SI";
 $modifica_clienti = "SI";
 $vedi_clienti = "SI";
@@ -266,8 +268,9 @@ $mese_fine = 4;
 else {
 $tipo_periodi_prec = "g";
 $importa_anno_prec = "NO";
-$mese_fine = 12;
-} # fine if ($num_ultimi_anni)
+if (date("n") > 8) $mese_fine = 24;
+else $mese_fine = 12;
+} # fine else if ($num_ultimi_anni)
 if ($tipo_periodi_prec == "s") {
 $tableperiodi_ua = $PHPR_TAB_PRE."periodi".$ultimo_anno;
 $giorno_ini_fine = esegui_query("select datainizio from $tableperiodi_ua where idperiodi = '1'");
@@ -421,7 +424,9 @@ $nuovo_mess = 0;
 $tablemessaggi = $PHPR_TAB_PRE."messaggi";
 $adesso = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
 $messaggi = esegui_query("select idmessaggi from $tablemessaggi where datavisione < '$adesso' and idutenti_visto $LIKE '%,$id_utente,%'");
-if (numlin_query($messaggi) > 0) $nuovo_mess = 1;
+if (numlin_query($messaggi) > 0) {
+$nuovo_mess = 1;
+} # fine if 
 } # fine if ($numconnessione)
 if ($nuovo_mess) {
 $gt = "<b style=\"color: red;\">&gt;</b>";
@@ -501,6 +506,7 @@ unlock_tabelle($tabelle_lock);
 if ($num_prenotazioni > 0) {
 if (!function_exists('dati_costi_agg_prenota')) include("./includes/funzioni_costi_agg.php");
 $fr_Appartamento = mex("Appartamento",'unit.php');
+$stile_data = stile_data();
 if (strlen($fr_Appartamento) > 4) $fr_Appartamento = substr($fr_Appartamento,0,3).".";
 echo "<table class=\"t1\" style=\"background-color: $t1color; margin-left: auto; margin-right: auto;\" width=780 border=\"$t1border\" cellspacing=\"$t1cellspacing\" cellpadding=\"$t1cellpadding\">
 <tr><td>N&deg;</td>
@@ -676,13 +682,13 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"crearegole.php\"><
 <input class=\"sbutton\" type=\"submit\" name=\"insregole\" value=\"".mex("Inserisci o modifica le regole di assegnazione",$pag)."\"><br>
 </div></form><div style=\"height: 10px\"></div>";
 } # fine if ($id_utente == 1 and $installazione_subordinata != "SI")
-if ($modifica_pers != "NO" or $priv_crea_backup == "s") {
+if ($modifica_pers != "NO" or $priv_crea_backup == "s"or $priv_crea_interconnessioni == "s") {
 echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"personalizza.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input class=\"sbutton\" type=\"submit\" name=\"insregole\" value=\"".mex("Configura e personalizza",$pag)."\"><br>
 </div></form><div style=\"height: 10px\"></div>";
-} # fine if ($modifica_pers != "NO" or $priv_crea_backup == "s")
+} # fine if ($modifica_pers != "NO" or $priv_crea_backup == "s"or $priv_crea_interconnessioni == "s")
 echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"inizio.php\"><div>
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 ".ucfirst(mex("richiedi l'anno",$pag))."
@@ -768,6 +774,10 @@ if (!$tipo_periodi_obbligati or $tipo_periodi_obbligati == "g") {
 echo "<label><input type=\"radio\" name=\"tipo_periodi\" value=\"g\"$checked_g>
 ".mex("giornalieri",$pag)."</label><br>";
 } # fine if (!$tipo_periodi_obbligati or $tipo_periodi_obbligati == "g")
+$sel_12 = "";
+$sel_24 = "";
+if (date("n") > 8) $sel_24 = " selected";
+else $sel_12 = " selected";
 echo "".mex("e prenotazioni da",$pag)."
  <select name=\"mese_ini\">
 <option value=\"1\" selected>".mex("Gennaio",$pag)."</option>
@@ -795,7 +805,7 @@ echo "".mex("e prenotazioni da",$pag)."
 <option value=\"9\">".mex("Settembre",$pag)."</option>
 <option value=\"10\">".mex("Ottobre",$pag)."</option>
 <option value=\"11\">".mex("Novembre",$pag)."</option>
-<option value=\"12\" selected>".mex("Dicembre",$pag)."</option>
+<option value=\"12\"$sel_12>".mex("Dicembre",$pag)."</option>
 <option value=\"13\">".mex("Gen",$pag).". ".mex("anno successivo",$pag)."</option>
 <option value=\"14\">".mex("Feb",$pag).". ".mex("anno successivo",$pag)."</option>
 <option value=\"15\">".mex("Mar",$pag).". ".mex("anno successivo",$pag)."</option>
@@ -807,7 +817,7 @@ echo "".mex("e prenotazioni da",$pag)."
 <option value=\"21\">".mex("Set",$pag).". ".mex("anno successivo",$pag)."</option>
 <option value=\"22\">".mex("Ott",$pag).". ".mex("anno successivo",$pag)."</option>
 <option value=\"23\">".mex("Nov",$pag).". ".mex("anno successivo",$pag)."</option>
-<option value=\"24\">".mex("Dic",$pag).". ".mex("anno successivo",$pag)."</option>";
+<option value=\"24\"$sel_24>".mex("Dic",$pag).". ".mex("anno successivo",$pag)."</option>";
 $n_mese[1] = mex("Gen",$pag);
 $n_mese[2] = mex("Feb",$pag);
 $n_mese[3] = mex("Mar",$pag);
