@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2013 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2014 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -55,22 +55,39 @@ if ($password) $password_phpr = $password;
 $id_utente_azione_ic = "";
 
 if (defined("C_UTENTE_AZIONE_IC") and C_UTENTE_AZIONE_IC != "" and $utente_azione_ic == C_UTENTE_AZIONE_IC) {
-$id_utente_az = esegui_query("select idlocale from $tableinterconnessioni where tipoid = 'id_utente_az' ");
-if (!numlin_query($id_utente_az)) {
+#$id_utente_az = esegui_query("select idlocale from $tableinterconnessioni where tipoid = 'id_utente_az' ");
+#if (!numlin_query($id_utente_az)) {
 $id_utente = "a";
 $id_utente_azione_ic = "a";
-$lingua_mex = "en";
-} # fine if (!numlin_query($id_utente_az))
+include(C_DATI_PATH."/lingua.php");
+$lingua_mex = $lingua[1];
+#} # fine if (!numlin_query($id_utente_az))
 } # fine if (defined("C_UTENTE_AZIONE_IC") and C_UTENTE_AZIONE_IC != "" and $utente_azione_ic == C_UTENTE_AZIONE_IC)
 
 if (!$id_utente_azione_ic) $id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_utente_phpr,$password_phpr,$anno);
 
-if ($id_utente and $id_utente != 1 and !$id_utente_azione_ic) {
+if ($id_utente != 1 and $id_utente != "a") {
+$privilegi_annuali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '$anno'");
+if (numlin_query($privilegi_annuali_utente) == 0) $anno_utente_attivato = "NO";
+else $anno_utente_attivato = "SI";
+$privilegi_globali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '1'");
+$priv_mod_pers = risul_query($privilegi_globali_utente,0,'priv_mod_pers');
+$priv_crea_interconnessioni = substr($priv_mod_pers,3,1);
+} # fine if ($id_utente != 1 and $id_utente != "a")
+else {
+if ($id_utente == 1) {
+$priv_crea_interconnessioni = "s";
+$anno_utente_attivato = "SI";
+} # fine if ($id_utente == 1)
+else $priv_crea_interconnessioni = "n";
+} # fine else if ($id_utente != 1 and $id_utente != "a")
+
+if ($id_utente and ($priv_crea_interconnessioni != "s" or $anno_utente_attivato != "SI") and !$id_utente_azione_ic) {
 $id_utente_az = esegui_query("select idlocale from $tableinterconnessioni where tipoid = 'id_utente_az' ");
 if (numlin_query($id_utente_az) == 1) $id_utente_azione_ic = risul_query($id_utente_az,0,'idlocale');
-} # fine if ($id_utente and $id_utente != 1 and !$id_utente_azione_ic)
+} # fine if ($id_utente and ($priv_crea_interconnessioni != "s" or $anno_utente_attivato != "SI") and !$id_utente_azione_ic)
 
-if ($id_utente and ($id_utente == 1 or $id_utente == $id_utente_azione_ic) and C_CREA_SUBORDINAZIONI != "NO") {
+if ($id_utente and (($priv_crea_interconnessioni == "s" and $anno_utente_attivato == "SI") or $id_utente == $id_utente_azione_ic) and C_CREA_SUBORDINAZIONI != "NO") {
 
 if (@is_file(C_DATI_PATH."/dati_subordinazione.php")) {
 $installazione_subordinata = "SI";
@@ -262,7 +279,7 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"./inizio.php\"><di
 } # fine if ($azione_ic == "SI" or $id_utente_azione_ic)
 
 
-if ($id_utente == 1) {
+if ($priv_crea_interconnessioni == "s") {
 
 
 
@@ -475,7 +492,7 @@ while ($mod_ext = readdir($interconn_dir)) {
 if ($mod_ext != "." and $mod_ext != ".." and @is_dir("./includes/interconnect/$mod_ext")) {
 include("./includes/interconnect/$mod_ext/name.php");
 if ($interconnection_name_show[$lingua_mex]) $titolo = $interconnection_name_show[$lingua_mex];
-else $titolo = $interconnection_name_show["en"];
+else $titolo = $interconnection_name_show['en'];
 echo "<hr style=\"width: 95%\"><div style=\"text-align: center;\"><b>$titolo</b></div><br>";
 include("./includes/interconnect/$mod_ext/form.php");
 } # fine if ($modello_ext != "." and $modello_ext != ".." and...
@@ -483,6 +500,37 @@ include("./includes/interconnect/$mod_ext/form.php");
 closedir($interconn_dir);
 
 
+$templates_dir = opendir("./includes/templates/");
+while ($modello_ext = readdir($templates_dir)) {
+if ($modello_ext != "." and $modello_ext != ".." and @is_dir("./includes/templates/$modello_ext")) {
+include("./includes/templates/$modello_ext/name.php");
+if ($template_name_show['tpl_type'] == "interconnection") {
+if (!function_exists('mex2')) {
+$perc_cart_mod_sel = "";
+include("./includes/templates/funzioni_modelli.php");
+$percorso_cartella_modello = $perc_cart_mod_vett[0];
+$anno_modello = $anno;
+$lingua_modello = $lingua_mex;
+} # fine if (!function_exists('mex2'))
+if ($template_name_show[$lingua_mex]) $titolo = $template_name_show[$lingua_mex];
+else {
+$messaggio = "";
+if (@is_file("./includes/lang/$lingua_mex/modt_$modello_ext.php")) {
+$messaggio = $template_name_show['ita'];
+include("./includes/lang/$lingua_mex/modt_$modello_ext.php");
+if ($messaggio == $template_name_show['ita']) $messaggio = "";
+} # fine if (@is_file("./includes/lang/$lingua_mex/modt_rat.php"))
+if ($messaggio) $titolo = $messaggio;
+else $titolo = $template_name_show['en'];
+} # fine else if ($template_name_show[$lingua_mex])
+echo "<hr style=\"width: 95%\"><div style=\"text-align: center;\"><b>$titolo</b></div><br>";
+include("./includes/templates/$modello_ext/form.php");
+} # fine if ($template_name_show['tpl_type'] == "interconnection")
+} # fine if ($modello_ext != "." and $modello_ext != ".." and...
+} # fine while ($file = readdir($lang_dig))
+closedir($templates_dir);
+
+
 echo "<hr style=\"width: 95%\"><div style=\"text-align: center;\">
 <form accept-charset=\"utf-8\" method=\"post\" action=\"./personalizza.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
@@ -494,13 +542,13 @@ echo "<hr style=\"width: 95%\"><div style=\"text-align: center;\">
 
 
 
-} # fine if ($id_utente == 1)
+} # fine if ($priv_crea_interconnessioni == "s")
 
 if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/foot.php");
 else include("./includes/foot.php");
 
 
-} # fine if ($id_utente and ($id_utente == 1 or $id_utente == $id_utente_azione_ic) and C_CREA_SUBORDINAZIONI != "NO")
+} # fine if ($id_utente and (($priv_crea_interconnessioni == "s" and $anno_utente_attivato == "SI") or $id_utente == $id_utente_azione_ic) and C_CREA_SUBORDINAZIONI != "NO")
 
 
 
