@@ -85,6 +85,16 @@ $tariffe_consentite = explode(",",substr($tariffe_consentite,2));
 unset($tariffe_consentite_vett);
 for ($num1 = 0 ; $num1 < count($tariffe_consentite) ; $num1++) if ($tariffe_consentite[$num1]) $tariffe_consentite_vett[$tariffe_consentite[$num1]] = "SI";
 } # fine if ($attiva_tariffe_consentite == "s")
+$costi_agg_consentiti = risul_query($privilegi_annuali_utente,0,'costi_agg_consentiti');
+$attiva_costi_agg_consentiti = substr($costi_agg_consentiti,0,1);
+if ($attiva_costi_agg_consentiti == "s") {
+$costi_agg_consentiti = explode(",",substr($costi_agg_consentiti,2));
+unset($costi_agg_consentiti_vett);
+for ($num1 = 0 ; $num1 < count($costi_agg_consentiti) ; $num1++) if ($costi_agg_consentiti[$num1]) $costi_agg_consentiti_vett[$costi_agg_consentiti[$num1]] = "SI";
+} # fine if ($attiva_costi_agg_consentiti == "s")
+$priv_ins_tariffe = risul_query($privilegi_annuali_utente,0,'priv_ins_tariffe');
+$priv_ins_costi_agg = substr($priv_ins_tariffe,1,1);
+if ($priv_ins_costi_agg == "g") $prendi_gruppi = "SI";
 } # fine else if (numlin_query($privilegi_annuali_utente) == 0)
 
 $priv_app_gruppi = "NO";
@@ -159,6 +169,8 @@ $priv_mod_beni_in_app = "s";
 $priv_mod_checkin = "s";
 $attiva_regole1_consentite = "n";
 $attiva_tariffe_consentite = "n";
+$attiva_costi_agg_consentiti = "n";
+$priv_ins_costi_agg = "s";
 } # fine else if ($id_utente != 1)
 if ($anno_utente_attivato == "SI") {
 
@@ -180,6 +192,9 @@ else include("./includes/head.php");
 
 
 
+$Euro = nome_valuta();
+$frase_modifica = "";
+
 if (!$url_enc) $idmag = htmlspecialchars($idmag);
 $idmag = aggslashdb($idmag);
 $idmag_orig = $idmag;
@@ -261,52 +276,179 @@ if ($manda_form_tab) {
 
 if ($aggiungi_bene) {
 if ($priv_ins_beni != "n") {
-if (strcmp($n_quantita_min_predef,"") and controlla_num_pos($n_quantita_min_predef) == "SI") {
+if (!strcmp($n_quantita_min_predef,"")) $n_quantita_min_predef = 0;
+if (controlla_num_pos($n_quantita_min_predef) == "SI") {
 if (!strcmp($n_quantita,"")) $n_quantita = $n_quantita_min_predef;
 if (controlla_num_pos($n_quantita) == "SI") {
 $n_id = aggslashdb($n_id);
 if ($ric_checkin != "s" or $tipoid != "idappartamento" or $priv_mod_checkin != "s") $ric_checkin = "n";
-$tabelle_lock = array("$tablerelinventario");
-$altre_tab_lock = array("$tablebeniinventario");
+if ($priv_ins_costi_agg == "n") $crea_ca = 0;
+if ($crea_ca) $tabelle_lock = array($tablenometariffe,$tableprivilegi,$tablerelinventario);
+else $tabelle_lock = array($tablerelinventario);
+$altre_tab_lock = array($tablebeniinventario);
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
-$n_id_esist = esegui_query("select idbeniinventario from $tablebeniinventario where idbeniinventario = '$n_id' ");
+$n_id_esist = esegui_query("select idbeniinventario,nome_bene from $tablebeniinventario where idbeniinventario = '$n_id' ");
 if (numlin_query($n_id_esist)) {
 $n_id_in_mag = esegui_query("select idbeneinventario from $tablerelinventario where idbeneinventario = '$n_id' and $tipoid = '$idmag' ");
 if (!numlin_query($n_id_in_mag)) {
+$nome_bene = risul_query($n_id_esist,0,'nome_bene');
+
+if ($crea_ca and !$continua) {
+$mostra_form_inventario = "NO";
+$nomi_esist = array();
+$nomecostoagg = $nome_bene;
+$costiagg_esist = esegui_query("select * from $tablenometariffe where nomecostoagg $LIKE '".aggslashdb($nomecostoagg)."%' and idntariffe > 10 ");
+for ($num1 = 0 ; $num1 < numlin_query($costiagg_esist) ; $num1++) $nomi_esist[risul_query($costiagg_esist,$num1,'nomecostoagg')] = 1;
+if ($nomi_esist[$nomecostoagg]) $nomecostoagg .= " *";
+while ($nomi_esist[$nomecostoagg]) $nomecostoagg .= "*";
+if ($tipoid == "idappartamento") $mag_esist = "app";
+else $mag_esist = "mag$idmag";
+$beniinv_ca_esist = esegui_query("select * from $tablenometariffe where beniinv_ca $LIKE '$mag_esist;%' and beniinv_ca $LIKE '%;$n_id,%' and idntariffe > 10 ");
+if (numlin_query($beniinv_ca_esist)) echo "<span class=\"colred\">".mex("Attenzione",$pag)."</span>: ".mex("esiste già un costo aggiuntivo associato a questo bene in questo magazzino",$pag).".<br>";
+$categorie_esist = esegui_query("select distinct categoria_ca from $tablenometariffe where beniinv_ca is not NULL and categoria_ca is not NULL and idntariffe > 10 order by categoria_ca ");
+$num_categorie_esist = numlin_query($categorie_esist);
+$categorie = array();
+for ($num1 = 0 ; $num1 < $num_categorie_esist ; $num1++) $categorie[risul_query($categorie_esist,$num1,'categoria_ca')] = 1;
+echo "<br>
+<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag#tab_inventario\"><div>
+<input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
+<input type=\"hidden\" name=\"origine\" value=\"$origine\">
+<input type=\"hidden\" name=\"origine_vecchia\" value=\"$origine_vecchia\">
+<input type=\"hidden\" name=\"tipo_tabella\" value=\"$tipo_tabella\">
+<input type=\"hidden\" name=\"idmag\" value=\"$idmag_orig\">
+<input type=\"hidden\" name=\"aggiorna_inventario\" value=\"SI\">
+<input type=\"hidden\" name=\"manda_form_tab\" value=\"SI\">
+<input type=\"hidden\" name=\"aggiungi_bene\" value=\"1\">
+<input type=\"hidden\" name=\"n_quantita_min_predef\" value=\"$n_quantita_min_predef\">
+<input type=\"hidden\" name=\"n_quantita\" value=\"$n_quantita\">
+<input type=\"hidden\" name=\"n_id\" value=\"$n_id\">
+<input type=\"hidden\" name=\"crea_ca\" value=\"1\">
+<input type=\"hidden\" name=\"continua\" value=\"1\">
+".mex("<em>Nome</em> del costo aggiuntivo",$pag).":
+ <input type=\"text\" name=\"nome_costo_agg\" value=\"$nomecostoagg\" size=\"24\"><br>
+<div style=\"height: 5px;\"></div>";
+if (!$num_categorie_esist) echo "<em>".mex("Categoria",$pag)."</em>: <input type=\"text\" name=\"n_categoria_ca\" size=\"24\"><br>";
+else {
+echo "<table cellpadding=\"0\" cellspacing=\"0\"><tr>
+<td style=\"vertical-align: top;\"><em>".mex("Categoria",$pag)."</em>:</td><td>
+<label><input type=\"radio\" id=\"tc_n\" name=\"tipo_categoria_ca\" value=\"nc\" checked>".mex("nuova",$pag).":
+ </label><input type=\"text\" name=\"n_categoria_ca\" size=\"24\" onfocus=\"document.getElementById('tc_n').checked='1'\"><br>
+<label><input type=\"radio\" id=\"tc_e\" name=\"tipo_categoria_ca\" value=\"ce\">".mex("esistente",$pag).":
+ </label><select name=\"categoria_esist_ca\" onfocus=\"document.getElementById('tc_e').checked='1'\">";
+reset($categorie);
+while (list($cat_es,$val) = each($categorie)) echo "<option value=\"".htmlspecialchars($cat_es)."\">".htmlspecialchars($cat_es)."</option>";
+echo "</select></td></tr></table>";
+} # fine else if (!$num_categorie_esist)
+echo "<div style=\"height: 5px;\"></div>
+".mex("<em>Prezzo</em> del costo aggiuntivo",$pag).":
+ <input type=\"text\" name=\"prezzo_costo_agg\" size=\"8\">$Euro<br>
+<div style=\"height: 5px;\"></div>
+<em>".mex("Tasse",'creaprezzi.php')."</em>: <input type=\"text\" name=\"tasseperc_ca\" value=\"$tasseperc_ca\" size=\"4\">%
+ <small>(".mex("il valore del costo si intente con tasse già incluse",'creaprezzi.php').")</small><br>
+<div style=\"height: 5px;\"></div>
+<input class=\"sbutton\" type=\"submit\" value=\"".mex("Continua",$pag)."\">
+</div></form><br><br><br>
+<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag#tab_inventario\"><div>
+<input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
+<input type=\"hidden\" name=\"origine\" value=\"$origine\">
+<input type=\"hidden\" name=\"origine_vecchia\" value=\"$origine_vecchia\">
+<input type=\"hidden\" name=\"tipo_tabella\" value=\"$tipo_tabella\">
+<input type=\"hidden\" name=\"idmag\" value=\"$idmag_orig\">
+<input class=\"sbutton\" type=\"submit\" value=\"".mex("Torna indietro",$pag)."\">
+</div></form><br>";
+} # fine if ($crea_ca and !$continua)
+
+else {
 $datainserimento = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
 esegui_query("insert into $tablerelinventario (idbeneinventario,$tipoid,quantita,quantita_min_predef,richiesto_checkin,datainserimento,hostinserimento,utente_inserimento) values ('$n_id','$idmag','$n_quantita','$n_quantita_min_predef','$ric_checkin','$datainserimento','$HOSTNAME','$id_utente') ");
-echo "".mex("Nuovo bene aggiunto",$pag).".<br>";
+$frase_modifica .= "".mex("Nuovo bene",$pag)." \"<em>$nome_bene</em>\" ".mex("aggiunto",$pag).".<br>";
+
+if ($crea_ca) {
+$prezzo_costo_agg = formatta_soldi($prezzo_costo_agg);
+if (strcmp($prezzo_costo_agg,"") and controlla_soldi($prezzo_costo_agg) == "SI") {
+if (get_magic_quotes_gpc()) $nome_costo_agg = stripslashes($nome_costo_agg);
+$costiagg_esist = esegui_query("select * from $tablenometariffe where nomecostoagg = '".aggslashdb($nome_costo_agg)."' and idntariffe > 10 ");
+if (!numlin_query($costiagg_esist)) {
+include_once("./includes/funzioni_costi_agg.php");
+$idntariffe = esegui_query("select numlimite_ca from $tablenometariffe where idntariffe = 1");
+$idntariffe = risul_query($idntariffe,0,0);
+if ($tipoid == "idappartamento") $beniinv_ca = "app";
+else $beniinv_ca = "mag$idmag";
+$beniinv_ca .= ";$n_id,1";
+esegui_query("insert into $tablenometariffe (idntariffe,nomecostoagg,tipo_ca,valore_ca,moltiplica_ca,beniinv_ca,variazione_ca,mostra_ca,letto_ca,regoleassegna_ca,utente_inserimento) values ('$idntariffe','".aggslashdb($nome_costo_agg)."','uf','$prezzo_costo_agg','cx0,','$beniinv_ca','nnnnnnsnn','nsns','n',';','$id_utente')");
+$tasseperc_ca = formatta_soldi($tasseperc_ca);
+if (controlla_soldi($tasseperc_ca) == "SI" and $tasseperc_ca <= 100 and $tasseperc_ca > 0) {
+esegui_query("update $tablenometariffe set tasseperc_ca = '".aggslashdb($tasseperc_ca)."' where idntariffe = '$idntariffe' ");
+} # fine if (controlla_soldi($tasseperc_ca) == "SI" and $tasseperc_ca <= 100 and $tasseperc_ca > 0)
+if ($tipo_categoria_ca != "ce") $categoria = $n_categoria_ca;
+else $categoria = $categoria_esist_ca;
+if ($categoria) {
+if (get_magic_quotes_gpc()) $categoria = stripslashes($categoria);
+esegui_query("update $tablenometariffe set categoria_ca = '".aggslashdb($categoria)."' where idntariffe = '$idntariffe' ");
+} # fine if ($categoria)
+aggiorna_privilegi_ins_costo($idntariffe,$tableprivilegi,$id_utente,$anno,$attiva_costi_agg_consentiti,$priv_ins_costi_agg,$utenti_gruppi);
+$idntariffe++;
+esegui_query("update $tablenometariffe set numlimite_ca = '$idntariffe' where idntariffe = 1");
+$frase_modifica .= "<form accept-charset=\"utf-8\" method=\"post\" action=\"modifica_costi.php\"><div>
+<input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
+<input type=\"hidden\" name=\"idntariffe\" value=\"".($idntariffe - 1)."\">
+<input type=\"hidden\" name=\"origine\" value=\"$pag?idmag=$idmag_orig&origine=visualizza_tabelle.php&tipo_tabella=inventario\">
+".mex("Il costo aggiuntivo",'creaprezzi.php')." \"<em>$nome_costo_agg</em>\" ".mex("è stato inserito",'creaprezzi.php').".
+ <input class=\"sbutton\" type=\"submit\" value=\"".mex("Modifica il costo",'creaprezzi.php')."\">
+</div></form>";
+} # fine if (!numlin_query($costiagg_esist))
+else $frase_modifica .= "<span class=\"colred\">".mex("Costo aggiuntivo non inserito",$pag)."</span>: ".mex("costo già esistente",$pag).".<br>";
+} # fine if (strcmp($prezzo_costo_agg,"") and controlla_soldi($prezzo_costo_agg) == "SI")
+else $frase_modifica .= "<span class=\"colred\">".mex("Costo aggiuntivo non inserito",$pag)."</span>: ".mex("prezzo sbagliato",$pag).".<br>";
+} # fine if ($crea_ca)
+} # fine else if ($crea_ca and !$continua)
+
 } # fine if (!numlin_query($n_id_in_mag))
 } # fine if (numlin_query($n_id_esist))
 unlock_tabelle($tabelle_lock);
 } # fine if (controlla_num_pos($n_quantita) == "SI")
-} # fine if (strcmp($n_quantita_min_predef,"") and...
+} # fine if (controlla_num_pos($n_quantita_min_predef) == "SI")
 } # fine if ($priv_ins_beni != "n")
 } # fine if ($aggiungi_bene)
 
 else {
 if ($priv_mod_beni != "n") {
-$tabelle_lock = array("$tablerelinventario");
-$altre_tab_lock = array("$tablebeniinventario");
+$tabelle_lock = array($tablerelinventario);
+$altre_tab_lock = array($tablepersonalizza,$tablebeniinventario);
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
-$beni_in_mag = esegui_query("select * from $tablerelinventario where $tipoid = '$idmag' order by idbeneinventario ");
+$ordine_inventario = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'ordine_inventario' and idutente = '$id_utente' ");
+$ordine_inventario = risul_query($ordine_inventario,0,'valpersonalizza');
+if ($ordine_inventario == "ins") $ordine_inventario = "$tablebeniinventario.idbeniinventario";
+else $ordine_inventario = "$tablebeniinventario.nome_bene";
+$beni_in_mag = esegui_query("select * from $tablerelinventario left outer join $tablebeniinventario on $tablerelinventario.idbeneinventario = $tablebeniinventario.idbeniinventario where $tablerelinventario.$tipoid = '$idmag' order by $ordine_inventario ");
 $num_beni_in_mag = numlin_query($beni_in_mag);
-$quantita_aggiornata = "NO";
+if ($tipo_nuova_quantita != "piu" and $tipo_nuova_quantita != "meno") $tipo_nuova_quantita = "nq";
+$frasi_quantita = "";
 for ($num1 = 0 ; $num1 < $num_beni_in_mag ; $num1++) {
-$id_bene_in_mag = risul_query($beni_in_mag,$num1,'idbeneinventario');
+$id_bene_in_mag = risul_query($beni_in_mag,$num1,'idbeneinventario',$tablerelinventario);
 if ($bene_permesso[$id_bene_in_mag]) {
 $n_quant = aggslashdb(${"n_quantita".$id_bene_in_mag});
 if (strcmp($n_quant,"") and controlla_num_pos($n_quant) == "SI") {
-$quantita = risul_query($beni_in_mag,$num1,'quantita');
+$quantita = risul_query($beni_in_mag,$num1,'quantita',$tablerelinventario);
+if ($tipo_nuova_quantita == "piu") $n_quant = $quantita + $n_quant;
+if ($tipo_nuova_quantita == "meno") $n_quant = $quantita - $n_quant;
+if ($n_quant < 0) $n_quant = 0;
 if ($quantita != $n_quant) {
 esegui_query("update $tablerelinventario set quantita = '$n_quant' where idbeneinventario = '$id_bene_in_mag' and $tipoid = '$idmag' ");
-$quantita_aggiornata = "SI";
+$nome_bene = risul_query($beni_in_mag,$num1,'nome_bene',$tablebeniinventario);
+$diff = $n_quant - $quantita;
+if ($diff < 0) $diff = "- ".substr($diff,1);
+else $diff = "+ $diff";
+$frasi_quantita .= "<b>$nome_bene</b>: $quantita $diff = $n_quant<br>";
 } # fine if ($quantita != $n_quant)
 } # fine if (strcmp($n_quant,"") and controlla_num_pos($n_quant) == "SI")
 } # fine if ($bene_permesso[$id_bene_in_mag])
 } # fine for $num1
 unlock_tabelle($tabelle_lock);
-if ($quantita_aggiornata == "SI") echo "<b>".mex("Quantità aggiornate",$pag)."</b>.<br>";
+if ($frasi_quantita) $frase_modifica .= "<b>".mex("Quantità aggiornate",$pag)."</b>:<br>$frasi_quantita";
 } # fine if ($priv_mod_beni != "n")
 } # fine else if ($aggiungi_bene)
 
@@ -316,8 +458,8 @@ if ($quantita_aggiornata == "SI") echo "<b>".mex("Quantità aggiornate",$pag)."<
 if ($ricarica and $id_bene and $priv_mod_beni != "n") {
 $id_bene = aggslashdb($id_bene);
 if ($bene_permesso[$id_bene]) {
-$tabelle_lock = array("$tablerelinventario");
-$altre_tab_lock = array("$tablenometariffe","$tableappartamenti","$tableregole","$tablebeniinventario","$tablemagazzini");
+$tabelle_lock = array($tablerelinventario);
+$altre_tab_lock = array($tablenometariffe,$tableappartamenti,$tableregole,$tablebeniinventario,$tablemagazzini);
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 $bene_in_mag = esegui_query("select * from $tablerelinventario where $tipoid = '$idmag' and idbeneinventario = '$id_bene' ");
 if (numlin_query($bene_in_mag) == 1) {
@@ -483,7 +625,7 @@ esegui_query("update $tablerelinventario set quantita = '$quantita' where $tipoi
 } # fine if ($priv_vedi_inv_app == "s" or $appartamenti_consentiti[$idapp] != "NO")
 } # fine if (${"app_da".$idapp_da} and...
 } # fine for $num1
-if ($ricaricato == "SI") echo "<b>".mex("Bene ricaricato",$pag)."</b>.<br>";
+if ($ricaricato == "SI") $frase_modifica .= "<b>".mex("Bene ricaricato",$pag)."</b>.<br>";
 } # fine else if ($ricarica != "continua")
 
 } # fine if ($num_diff < 0)
@@ -501,9 +643,9 @@ $altre_tab_lock = array("$tablebeniinventario");
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 $id_bene_in_mag = esegui_query("select idbeneinventario from $tablerelinventario where idbeneinventario = '$id_bene' and $tipoid = '$idmag' limit 1");
 if (numlin_query($id_bene_in_mag)) {
-if (!$elimina_cont) {
 $nome_bene = esegui_query("select nome_bene from $tablebeniinventario where idbeniinventario = '$id_bene'");
 $nome_bene = risul_query($nome_bene,0,'nome_bene');
+if (!$elimina_cont) {
 $mostra_form_inventario = "NO";
 echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
@@ -525,7 +667,7 @@ echo " <b>$nome_mag</b>?<br>
 } # fine if (!$elimina_cont)
 else {
 esegui_query("delete from $tablerelinventario where idbeneinventario = '$id_bene' and $tipoid = '$idmag' ");
-echo "<b>".mex("Bene cancellato",$pag)."</b>.<br>";
+$frase_modifica .= "<b>".mex("Bene",$pag)." \"<em>$nome_bene</em>\" ".mex("cancellato",$pag)."</b>.<br>";
 } # fine else if (!$elimina_cont)
 } # fine if (numlin_query($id_bene_in_mag))
 unlock_tabelle($tabelle_lock);
@@ -540,8 +682,26 @@ unlock_tabelle($tabelle_lock);
 if ($mostra_form_inventario != "NO") {
 if ($tipoid == "idappartamento") echo "<h3>".mex("Inventario dell'appartamento",'unit.php')." <b>$nome_mag</b>.</h3><br>";
 else echo "<h3>".mex("Inventario del magazzino",$pag)." $nome_mag.</h3><br>";
+if ($frase_modifica) echo "$frase_modifica<div style=\"height: 5px;\"></div>";
 
-echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
+if ($priv_mod_beni != "n") {
+echo "<script type=\"text/javascript\">
+<!--
+function simb_tipo_quant () {
+var val_sel = document.getElementById('ti_nq');
+val_sel = val_sel.options[val_sel.selectedIndex].value;
+var n_simb = '';
+if (val_sel == 'piu') n_simb = '+';
+if (val_sel == 'meno') n_simb = '-';
+var simb_nq = document.getElementsByClassName('simb_nq');
+for (var n1 = 0; n1 < simb_nq.length; n1++) simb_nq[n1].innerHTML = n_simb;
+}
+-->
+</script>
+";
+} # fine if ($priv_mod_beni != "n")
+
+echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag#tab_inventario\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"origine\" value=\"$origine\">
@@ -554,7 +714,13 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
 <tr><td>".mex("Nome bene",$pag)."</td>
 <td style=\"line-height: 70%\"><small><small>".mex("Quantità minima predefinita",$pag)."</small></small></td>
 <td><small>".mex("Quantità attuale",$pag)."</small></td>";
-if ($priv_mod_beni != "n") echo "<td><small>".mex("Nuova quantità",$pag)."</small></td>";
+if ($priv_mod_beni != "n") {
+echo "<td><select id=\"ti_nq\" class=\"smallsel85\" name=\"tipo_nuova_quantita\" onchange=\"simb_tipo_quant();\">
+<option value=\"nq\" selected>".mex("Nuova quantità",$pag)."</option>
+<option value=\"piu\">".mex("Aggiungi",$pag)."</option>
+<option value=\"meno\">".mex("Sottrai",$pag)."</option>
+</select></td>";
+} # fine if ($priv_mod_beni != "n")
 if ($priv_ins_beni != "n" or $priv_mod_beni != "n") {
 if ($tipoid == "idappartamento" or $priv_mod_checkin != "s") {
 $attiva_checkin = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'attiva_checkin' and idutente = '$id_utente'");
@@ -565,9 +731,15 @@ echo "<td>".mex("Modifica",$pag)."</td>";
 } # fine if ($priv_ins_beni != "n" or $priv_mod_beni != "n")
 echo "</tr>";
 
-$beni_in_mag = esegui_query("select * from $tablerelinventario where $tipoid = '$idmag' order by idbeneinventario ");
+$ordine_inventario = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'ordine_inventario' and idutente = '$id_utente' ");
+$ordine_inventario = risul_query($ordine_inventario,0,'valpersonalizza');
+if ($ordine_inventario == "ins") $ordine_inventario = "idbeniinventario";
+else $ordine_inventario = "nome_bene";
+
+if ($ordine_inventario == "idbeniinventario") $beni_in_mag = esegui_query("select * from $tablerelinventario where $tipoid = '$idmag' order by idbeneinventario ");
+else $beni_in_mag = esegui_query("select * from $tablerelinventario left outer join $tablebeniinventario on $tablerelinventario.idbeneinventario = $tablebeniinventario.idbeniinventario where $tablerelinventario.$tipoid = '$idmag' order by $tablebeniinventario.nome_bene ");
 $num_beni_in_mag = numlin_query($beni_in_mag);
-$beni_inv = esegui_query("select * from $tablebeniinventario $condizione_beni_propri order by idbeniinventario");
+$beni_inv = esegui_query("select * from $tablebeniinventario $condizione_beni_propri order by $ordine_inventario");
 $num_beni_inv = numlin_query($beni_inv);
 if ($priv_vedi_beni_inv == "n") $num_beni_inv = 0;
 
@@ -583,11 +755,11 @@ $codici_beni[$idinv] = risul_query($beni_inv,$num1,'codice_bene');
 
 unset($id_in_mag);
 for ($num1 = 0 ; $num1 < $num_beni_in_mag ; $num1++) {
-$id_bene_in_mag = risul_query($beni_in_mag,$num1,'idbeneinventario');
+$id_bene_in_mag = risul_query($beni_in_mag,$num1,'idbeneinventario',$tablerelinventario);
 if ($bene_permesso[$id_bene_in_mag]) {
-$quantita = risul_query($beni_in_mag,$num1,'quantita');
-$quantita_min_predef = risul_query($beni_in_mag,$num1,'quantita_min_predef');
-$richiesto_checkin = risul_query($beni_in_mag,$num1,'richiesto_checkin');
+$quantita = risul_query($beni_in_mag,$num1,'quantita',$tablerelinventario);
+$quantita_min_predef = risul_query($beni_in_mag,$num1,'quantita_min_predef',$tablerelinventario);
+$richiesto_checkin = risul_query($beni_in_mag,$num1,'richiesto_checkin',$tablerelinventario);
 $id_in_mag[$id_bene_in_mag] = 1;
 $nome_bene = $nomi_beni[$id_bene_in_mag];
 if ($codici_beni[$id_bene_in_mag]) $nome_bene .= " (".$codici_beni[$id_bene_in_mag].")";
@@ -603,10 +775,12 @@ else {
 if (substr($diff,0,1) != "-") $diff = "+".$diff;
 $diff = "<small><small> ($diff)</small></small>";
 } # fine else if (!$diff)
-echo "<tr><td>$nome_bene</td>
+if ($aggiungi_bene and ($num1 == ($num_beni_inv - 12) or ($num1 == 0 and ($num_beni_inv - 12) < 0))) $anchor = "<a name=\"tab_inventario\"></a>";
+else $anchor = "";
+echo "<tr><td>$anchor$nome_bene</td>
 <td>$quantita_min_predef</td>
 <td$colore>$quantita$diff</td>";
-if ($priv_mod_beni != "n") echo "<td><input type=\"text\" name=\"n_quantita$id_bene_in_mag\" size=\"5\"></td>";
+if ($priv_mod_beni != "n") echo "<td><span class=\"simb_nq\"></span><input type=\"text\" name=\"n_quantita$id_bene_in_mag\" size=\"5\"></td>";
 if ($priv_ins_beni != "n" or $priv_mod_beni != "n") {
 if ($attiva_checkin == "SI") {
 if ($richiesto_checkin == "s") echo "<td>".ucfirst(mex("si",$pag))."</td>";
@@ -634,10 +808,16 @@ $opt_beni .= "</option>";
 } # fine for $num1
 
 if ($opt_beni and $priv_ins_beni != "n") {
+if ($aggiungi_bene) $autofocus = " autofocus";
+else $autofocus = "";
 echo "<tr><td><select name=\"n_id\">$opt_beni</select></td>
 <td><input type=\"text\" name=\"n_quantita_min_predef\" size=\"5\"></td>
-<td><input type=\"text\" name=\"n_quantita\" size=\"5\"></td>
-<td>&nbsp;</td>";
+<td><input type=\"text\" name=\"n_quantita\" size=\"5\"$autofocus></td>";
+if ($priv_ins_costi_agg != "n") {
+echo "<td><small style=\"white-space: nowrap;\"><label><input type=\"checkbox\" name=\"crea_ca\" value=\"1\" style=\"width: 14px; height: 12px;\">";
+echo "".mex("crea un <em>costo aggiuntivo</em>",$pag)."<br> ".mex("per il punto vendita",$pag).".</label></td>";
+} # fine if ($priv_ins_costi_agg != "n")
+else echo "<td>&nbsp;</td>";
 if ($attiva_checkin == "SI") {
 echo "<td><select name=\"ric_checkin\">
 <option value=\"s\">".ucfirst(mex("si",$pag))."</option>
@@ -649,7 +829,8 @@ echo "<td>".mex("<input class=\"sbutton\" type=\"submit\" name=\"aggiungi_bene\"
 
 echo "</table><br><div style=\"text-align: center;\">";
 if ($priv_mod_beni != "n") echo "<input class=\"sbutton\" type=\"submit\" name=\"modifica_quantita\" value=\"".mex("Modifica le quantità attuali",$pag)."\">";
-echo "</div></div></form><br>";
+echo "</div></div></form>
+$frase_modifica<br>";
 
 
 echo "<hr style=\"width: 95%\"><br><div style=\"text-align: center;\">
@@ -659,7 +840,7 @@ echo "<hr style=\"width: 95%\"><br><div style=\"text-align: center;\">
 <input type=\"hidden\" name=\"tipo_tabella\" value=\"$tipo_tabella\">";
 if ($origine_vecchia) echo "<input type=\"hidden\" name=\"origine\" value=\"$origine_vecchia\">";
 echo "<input class=\"sbutton\" type=\"submit\" name=\"torna\" value=\"".mex("Torna indietro",$pag)."\">
-</div></form></div>";
+</div></form><br></div>";
 
 } # fine if ($mostra_form_inventario != "NO")
 
