@@ -58,9 +58,9 @@ $priv_ins_messaggi = substr($priv_messaggi,1,1);
 $contratti_consentiti = risul_query($privilegi_annuali_utente,0,'contratti_consentiti');
 $attiva_contratti_consentiti = substr($contratti_consentiti,0,1);
 if ($attiva_contratti_consentiti == "s") {
-$contratti_consentiti = explode(",",substr($contratti_consentiti,2));
+$contratti_consentiti = explode(",",$contratti_consentiti);
 unset($contratti_consentiti_vett);
-for ($num1 = 0 ; $num1 < count($contratti_consentiti) ; $num1++) if ($contratti_consentiti[$num1]) $contratti_consentiti_vett[$contratti_consentiti[$num1]] = "SI";
+for ($num1 = 1 ; $num1 < count($contratti_consentiti) ; $num1++) if ($contratti_consentiti[$num1]) $contratti_consentiti_vett[$contratti_consentiti[$num1]] = "SI";
 } # fine if ($attiva_contratti_consentiti == "s")
 $costi_agg_consentiti = risul_query($privilegi_annuali_utente,0,'costi_agg_consentiti');
 $attiva_costi_agg_consentiti = substr($costi_agg_consentiti,0,1);
@@ -277,12 +277,13 @@ $tabelle_lock = array($tablemessaggi);
 $altre_tab_lock = array($tableutenti,$tableprivilegi);
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 $adesso = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
-$messaggi = esegui_query("select idmessaggi,idutenti from $tablemessaggi where datavisione < '$adesso'$cond_data_arrivo and idutenti $LIKE '%,$id_utente,%'");
+$messaggi = esegui_query("select idmessaggi,idutenti,idutenti_visto from $tablemessaggi where datavisione < '$adesso'$cond_data_arrivo and idutenti $LIKE '%,$id_utente,%'");
 $num_messaggi = numlin_query($messaggi);
 for ($num1 = 0 ; $num1 < $num_messaggi ; $num1++) {
 $idmessaggi = risul_query($messaggi,$num1,'idmessaggi');
 $idutenti = risul_query($messaggi,$num1,'idutenti');
-esegui_query("update $tablemessaggi set idutenti = '".str_replace(",$id_utente,",",",$idutenti)."' where idmessaggi = '$idmessaggi'");
+$idutenti_visto = risul_query($messaggi,$num1,'idutenti_visto');
+esegui_query("update $tablemessaggi set idutenti = '".str_replace(",$id_utente,",",",$idutenti)."', idutenti_visto = '".str_replace(",$id_utente,",",",$idutenti_visto)."' where idmessaggi = '$idmessaggi'");
 } # fine for $num1
 cancella_messaggi_vecchi($tableprivilegi,$tablemessaggi);
 unlock_tabelle($tabelle_lock);
@@ -355,15 +356,15 @@ $riferimento = $info_mess[$num1]->references;
 $oggetto = utf8_encode(imap_qprint($info_mess[$num1]->subject));
 $inserisci_mess = 0;
 for ($num2 = 0 ; $num2 < $num_trova_email_tm ; $num2++) {
-if ($mittente == $mittente_email_tm[$num2] or stristr($mittente,"<".$mittente_email_tm[$num2].">") or !$mittente_email_tm[$num2]) {
-if (stristr($oggetto,$oggetto_email_tm[$num2])) {
-if ($therad_email_tm[$num2] == "tutti" or (!$risposta_a and !$riferimento)) {
+if (!$mittente_email_tm[$num2] or stristr($mittente,$mittente_email_tm[$num2])) {
+if (!strcmp($oggetto_email_tm[$num2],"") or stristr($oggetto,$oggetto_email_tm[$num2])) {
+if ($therad_email_tm[$num2] == "tutti" or (!$risposta_a and !$riferimento and substr($oggetto,0,4) != "Re: ")) {
 $inserisci_mess = 1;
 $mess_scaricati++;
 break;
-} # fine if ($therad_email_tm[$num2] == "tutti" or...
-} # fine if (stristr($oggetto,$oggetto_email_tm[$num2]))
-} # fine if ($mittente == $mittente_email_tm[$num2] or...
+} # fine if ($therad_email_tm[$num2] == "tutti" or (!$risposta_a and...
+} # fine if (!strcmp($oggetto_email_tm[$num2],"") or stristr($oggetto,$oggetto_email_tm[$num2]))
+} # fine if (!$mittente_email_tm[$num2] or stristr($mittente,$mittente_email_tm[$num2]))
 } # fine for $num2
 
 if ($inserisci_mess) {
@@ -372,7 +373,7 @@ $datavisione = date("Y-m-d H:i",(time() + (C_DIFF_ORE * 3600))).":00";
 $datainserimento = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
 if (strstr($mittente,"<")) $mittente = substr(strstr($mittente,"<"),1,-1);
 $eml_header = imap_headerinfo($email_conn,$mess[$num1]);
-#echo "<br><br>".var_dump($header)."<br><br>";
+#echo "<br><br>".var_dump($eml_header)."<br><br>";
 $mittente = "";
 $nome_cognome_richiedente = "";
 $eml_reply_to = $eml_header->reply_to;
@@ -391,26 +392,34 @@ for ($num2 = 0 ; $num2 < count($eml_cc) ; $num2++) $mittente .= ",".$eml_cc[$num
 } # fine if (is_array($eml_cc) and count($eml_cc) > 0)
 } # fine else if (is_array($reply_to) and count($reply_to) > 0)
 #if (strstr($mittente,"<")) $mittente = substr(strstr($mittente,"<"),1,-1);
-$testo = utf8_encode(imap_qprint(imap_body($email_conn,$mess[$num1],FT_PEEK)));
-if (@get_magic_quotes_gpc()) $testo = stripslashes($testo);
-$testo = htmlspecialchars($testo);
-$testo = aggslashdb($testo);
-if (stristr($testo,"Content-Type: multipart/alternative;") and stristr($testo,"Content-Type: text/plain;")) {
-$testo = explode("------=_Part",$testo);
+$testo = imap_utf8(imap_qprint(imap_body($email_conn,$mess[$num1],FT_PEEK)));
+#if (@get_magic_quotes_gpc()) $testo = stripslashes($testo);
+if (strlen($testo) > 30 and preg_replace("|[a-z0-9+/=]|i","",str_replace("\n","",str_replace("\r","",trim($testo)))) == "") $testo = imap_utf8(base64_decode($testo));
+if ((stristr($testo,"Content-Type: multipart/alternative;") or stristr($testo,"This is a multi-part message in MIME format")) and stristr($testo,"Content-Type: text/plain;")) {
+if (stristr($testo,"------=_Part")) $testo = explode("------=_Part",$testo);
+else $testo = explode("Content-Type: ",$testo);
 for ($num2 = 0 ; $num2 < count($testo) ; $num2++) {
-if (stristr($testo[$num2],"Content-Type: text/plain;")) {
+if (stristr("Content-Type: ".$testo[$num2],"Content-Type: text/plain;")) {
 $testo = str_replace("\r","\n",str_replace("\r\n","\n",$testo[$num2]));
 if (strstr($testo,"\n\n")) $testo = (strstr($testo,"\n\n"));
 break;
-} # fine if (stristr($testo[$num2],"Content-Type: text/plain;"))
+} # fine if (stristr("Content-Type: ".$testo[$num2],"Content-Type: text/plain;"))
 } # fine for $num2
 } # fine if (stristr($testo,"Content-Type: multipart/alternative;") and...
 else {
-if (stristr($testo,"Content-Type: text/html;")) {
-$testo = strip_tags(str_replace("<br>","\n",str_replace("<BR>","\n",str_replace("</div>","\n",str_replace("</DIV>","\n",str_replace("</tr>","\n",str_replace("</TR>","\n",$testo)))))));
-} # fine if (stristr($testo,"Content-Type: text/html;"))
+if (stristr($testo,"Content-Type: text/html;") or stristr($testo,"<html>")) {
+$testo = str_replace("\r","",str_replace("\n","",$testo));
+$testo = str_replace("<br>","\n",str_replace("<BR>","\n",str_replace("</div>","\n",str_replace("</DIV>","\n",str_replace("</tr>","\n",str_replace("</TR>","\n",$testo))))));
+$testo = str_replace("<br/>","\n",str_replace("<BR/>","\n",$testo));
+$testo = preg_replace("/<![a-z-][^>]*>/i","",preg_replace("|</?[a-z][^>]*>|i","",preg_replace("|<head>.*</head>|s","",str_replace("&nbsp;"," ",$testo))));
+$testo = preg_replace("/^ +/m","",str_replace("	"," ",$testo));
+while (strstr($testo,"\n\n\n")) $testo = str_replace("\n\n\n","\n\n",$testo);
+} # fine if (stristr($testo,"Content-Type: text/html;") or stristr($testo,"<html>"))
 } # fine else if (stristr($testo,"Content-Type: multipart/alternative;") and...
-$dati_richiedente = "$nome_cognome_richiedente<d><d>$mittente<d><d><d><d><d><d><d><d><d><d><d><d><d><d>";
+if (!defined('ENT_SUBSTITUTE')) define('ENT_SUBSTITUTE',ENT_IGNORE);
+$testo = htmlspecialchars($testo,ENT_SUBSTITUTE);
+$testo = aggslashdb($testo);
+$dati_richiedente = "$nome_cognome_richiedente<d><d>$mittente<d><d><d><d><d><d><d><d><d><d><d><d><d><d><d><d>";
 esegui_query("insert into $tablemessaggi (idmessaggi,tipo_messaggio,idutenti,idutenti_visto,datavisione,mittente,testo,dati_messaggio1,dati_messaggio3,dati_messaggio8,dati_messaggio15,dati_messaggio20,datainserimento) values ('$max_mess','rprenota','$lista_utenti','$lista_utenti','$datavisione','$mittente','".aggslashdb($testo)."','da_inserire','1','1','".aggslashdb($dati_richiedente)."','email','$datainserimento')");
 
 # Estrazione dati da testo email
@@ -443,12 +452,14 @@ $lingua_orig = $lingua_mex;
 $lingua_mex = $lingue[$num2];
 $fr_arrivo = mex("arrivo",$pag);
 $fr_partenza = mex("partenza",$pag);
+$fr_date = mex("date",$pag);
 $fr_persone = mex("persone",$pag);
 $lingua_mex = $lingua_orig;
 if (!$arrivo_trovato and !$arrivo_cercato[$fr_arrivo]) {
 $arrivo_cercato[$fr_arrivo] = 1;
 # strano syntax error se si rimuove "." (dovuto a riconoscimento array?)
 $arrivo = preg_split("/$fr_arrivo"."[^0-9a-z]/i",$testo);
+if (!$arrivo[1]) $arrivo = preg_split("/$fr_date"."[^0-9a-z]/i",$testo);
 if ($arrivo[1]) {
 $arrivo = preg_split("/$fr_partenza"."[^0-9a-z]/i",substr($testo,strlen($arrivo[0])));
 $arrivo = trova_prima_data(substr($arrivo[0],0,40),$stile_data,$lingue[$num2]);
@@ -471,6 +482,7 @@ $fr_ospiti = mex("ospiti",$pag);
 $fr_gruppo = mex("gruppo",$pag);
 $fr_adulti = mex("adulti",$pag);
 $fr_bambini = mex("bambini",$pag);
+$fr_viaggiatori = mex("viaggiatori",$pag);
 $lingua_mex = $lingua_orig;
 $num_persone = trova_numero_vicino($testo,$fr_adulti);
 if ($num_persone) {
@@ -483,7 +495,10 @@ if (!$num_persone) {
 $num_persone = trova_numero_vicino($testo,$fr_gruppo);
 if (!$num_persone) {
 $num_persone = trova_numero_vicino($testo,$fr_persone2);
-if (!$num_persone) $num_persone = trova_numero_vicino($testo,$fr_persone);
+if (!$num_persone) {
+$num_persone = trova_numero_vicino($testo,$fr_persone);
+if (!$num_persone) $num_persone = trova_numero_vicino($testo,$fr_viaggiatori);
+} # fine if (!$num_persone)
 } # fine if (!$num_persone)
 } # fine if (!$num_persone)
 } # fine else if ($num_persone)
@@ -690,9 +705,6 @@ $stringa_puntini_tab = "<tr><td colspan=\"5\" style=\"text-align: center;\">...<
 } # fine if ($num_messaggi > $num_vedi_in_tab)
 else $num_pagine = 1;
 
-$orario_tab_messaggi = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'mostra_orario_tab_messaggi' and idutente = '$id_utente'");
-$orario_tab_messaggi = risul_query($orario_tab_messaggi,0,'valpersonalizza');
-
 function crea_tasto_modifica_prenota ($stato_prenota,$priv_mod_prenota_iniziate,$priv_mod_prenotazioni,$priv_mod_prenota_ore,$anno,$PHPR_TAB_PRE,$pag,$id_sessione,$id_utente) {
 $tableprenota = $PHPR_TAB_PRE."prenota".$anno;
 $tasto_prenota = str_replace(" ","&nbsp;",mex("Inserito",$pag)).": ";
@@ -868,6 +880,11 @@ $min_stima_checkin = substr($oracheckin,14,2);
 $oracheckin = $oracheckin.":00";
 } # fine if ($oracheckin)
 $metodo_pagamento = $dati_richiedente_dt[17];
+$commento = $dati_richiedente_dt[20];
+$commenti_pers = explode(">",$dati_richiedente_dt[21]);
+$num_commenti_pers = count($commenti_pers);
+if ($num_commenti_pers < 1) $num_commenti_pers = 1;
+$campi_pers_clienti = $dati_richiedente_dt[22];
 
 if ($stato_prenota == "da_inserire") {
 if ($priv_ins_nuove_prenota == "s" and $inizioperiodo[1]) {
@@ -876,8 +893,8 @@ $tasto_prenota = "<form accept-charset=\"utf-8\" method=\"post\" action=\"prenot
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"idmessaggi\" value=\"$idmessaggi\">
 <input type=\"hidden\" name=\"cognome\" value=\"$cognome_richiedente\">
-<input type=\"hidden\" name=\"nome\" value=\"$nome_richiedente\">
-<input type=\"hidden\" name=\"mos_tut_dat\" value=\"SI\">
+<input type=\"hidden\" name=\"nome\" value=\"$nome_richiedente\">";
+$tasto_prenota .= "<input type=\"hidden\" name=\"mos_tut_dat\" value=\"SI\">
 <input type=\"hidden\" name=\"num_tipologie\" value=\"$num_tipologie\">";
 for ($n_t = 1 ; $n_t <= $num_tipologie ; $n_t++) {
 $tasto_prenota .= "<input type=\"hidden\" name=\"inizioperiodo$n_t\" value=\"".$idinizioperiodo[$n_t]."\">
@@ -886,7 +903,14 @@ $tasto_prenota .= "<input type=\"hidden\" name=\"inizioperiodo$n_t\" value=\"".$
 <input type=\"hidden\" name=\"num_app_richiesti$n_t\" value=\"".$num_app_tipo_richiesti[$n_t]."\">
 <input type=\"hidden\" name=\"nometipotariffa$n_t\" value=\"tariffa".$numero_tariffa[$n_t]."\">
 <input type=\"hidden\" name=\"met_paga_caparra$n_t\" value=\"$metodo_pagamento\">
-<input type=\"hidden\" name=\"origine_prenota$n_t\" value=\"$origine_prenota_dt\">";
+<input type=\"hidden\" name=\"origine_prenota$n_t\" value=\"$origine_prenota_dt\">
+<input type=\"hidden\" name=\"commento1_$n_t\" value=\"$commento\">
+<input type=\"hidden\" name=\"num_commenti$n_t\" value=\"$num_commenti_pers\">";
+for ($num2 = 1 ; $num2 < count($commenti_pers) ; $num2++) {
+$commento_pers = explode("<",$commenti_pers[$num2]);
+$tasto_prenota .= "<input type=\"hidden\" name=\"tipo_commento".($num2 + 1)."_$n_t\" value=\"".$commento_pers[0]."\">
+<input type=\"hidden\" name=\"commento".($num2 + 1)."_$n_t\" value=\"".$commento_pers[1]."\">";
+} # fine for $num2
 if ($oracheckin) {
 $anno_ini = substr($inizioperiodo[$n_t],0,4);
 $mese_ini = substr($inizioperiodo[$n_t],5,2);
@@ -929,7 +953,7 @@ $tasto_prenota .= "<form accept-charset=\"utf-8\" method=\"post\" action=\"dispo
 <input type=\"hidden\" name=\"testo_email_richiesta\" value=\"".str_replace("\"","&quot;",$testo_orig)."\">
 <input type=\"hidden\" name=\"inizioperiodo\" value=\"".$inizioperiodo[1]."\">
 <input type=\"hidden\" name=\"fineperiodo\" value=\"".$fineperiodo[1]."\">
-<input type=\"hidden\" name=\"origine\" value=\"messaggi.php#mess$idmessaggi\">";
+<input type=\"hidden\" name=\"origine\" value=\"messaggi.php?pagina_messaggi=$pagina_messaggi#mess$idmessaggi\">";
 if ($numpersone[1]) $tasto_prenota .= "<input type=\"hidden\" name=\"numpersone\" value=\"".$numpersone[1]."\">";
 $tasto_prenota .= "<input class=\"sbutton\" type=\"submit\" value=\"".mex("Controlla disponibilità",$pag)."\">
 </div></form><br>";
@@ -940,7 +964,7 @@ if ($option_contratti) {
 $tasto_contr = "<form accept-charset=\"utf-8\" method=\"post\" action=\"visualizza_contratto.php\"><div class=\"linhbox\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
-<input type=\"hidden\" name=\"origine\" value=\"messaggi.php#mess$idmessaggi\">";
+<input type=\"hidden\" name=\"origine\" value=\"messaggi.php?pagina_messaggi=$pagina_messaggi#mess$idmessaggi\">";
 $n_c = 0;
 for ($n_t = 1 ; $n_t <= $num_tipologie ; $n_t++) {
 for ($n_r = 1 ; $n_r <= $num_app_tipo_richiesti[$n_t] ; $n_r++) {
@@ -1028,6 +1052,7 @@ if ($aggiunta_testo_dt) {
 echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag#mess$idmessaggi\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
+<input type=\"hidden\" name=\"pagina_messaggi\" value=\"$pagina_messaggi\">
 <input type=\"hidden\" name=\"cambia_qualcosa\" value=\"SI\">
 <input type=\"hidden\" name=\"cambia_dati_ricavati\" value=\"$idmessaggi\">
 -------------------------<br>
