@@ -84,9 +84,9 @@ if ($priv_vedi_tab_prenotazioni == "g") $prendi_gruppi = "SI";
 $contratti_consentiti = risul_query($privilegi_annuali_utente,0,'contratti_consentiti');
 $attiva_contratti_consentiti = substr($contratti_consentiti,0,1);
 if ($attiva_contratti_consentiti == "s") {
-$contratti_consentiti = explode(",",substr($contratti_consentiti,2));
+$contratti_consentiti = explode(",",$contratti_consentiti);
 unset($contratti_consentiti_vett);
-for ($num1 = 0 ; $num1 < count($contratti_consentiti) ; $num1++) if ($contratti_consentiti[$num1]) $contratti_consentiti_vett[$contratti_consentiti[$num1]] = "SI";
+for ($num1 = 1 ; $num1 < count($contratti_consentiti) ; $num1++) if ($contratti_consentiti[$num1]) $contratti_consentiti_vett[$contratti_consentiti[$num1]] = "SI";
 } # fine if ($attiva_contratti_consentiti == "s")
 $priv_mod_prenota = risul_query($privilegi_annuali_utente,0,'priv_mod_prenota');
 $priv_mod_prenotazioni = substr($priv_mod_prenota,0,1);
@@ -794,6 +794,9 @@ $cert_cc = esegui_query("select valpersonalizza from $tablepersonalizza where id
 if (numlin_query($cert_cc)) {
 $mostra_form_modifica_cliente = "NO";
 
+$gest_cvc = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'gest_cvc' and idutente = '1'");
+$gest_cvc = risul_query($gest_cvc,0,'valpersonalizza');
+
 $tipo_transazione = "";
 if ($id_transazione) recupera_dati_transazione($id_transazione,$id_sessione,$anno,"SI",$tipo_transazione);
 if ($tipo_transazione == "mo_cc") {
@@ -813,14 +816,14 @@ $errore = "SI";
 echo ucfirst(mex("il numero di carta di credito è <span class=\"colred\">sbagliato</span>",$pag));
 } # fine if (preg_replace("/[0-9]*/","",$n_num_cc) != "")
 } # fine if ($n_num_cc)
-#if ($n_cvc_cc) {
-#$n_cvc_cc = str_replace(" ","",$n_cvc_cc);
-#if (preg_replace("/[0-9]*/","",$n_cvc_cc) != "") {
-#$errore = "SI";
-#echo ucfirst(mex("il numero CVC è <span class=\"colred\">sbagliato</span>",$pag));
-#} # fine if (preg_replace("/[0-9]*/","",$n_cvc_cc) != "")
-#} # fine if ($n_cvc_cc)
-$n_cvc_cc = "";
+if ($n_cvc_cc) {
+$n_cvc_cc = str_replace(" ","",$n_cvc_cc);
+if (preg_replace("/[0-9]*/","",$n_cvc_cc) != "") {
+$errore = "SI";
+echo ucfirst(mex("il numero CVC è <span class=\"colred\">sbagliato</span>",$pag));
+} # fine if (preg_replace("/[0-9]*/","",$n_cvc_cc) != "")
+} # fine if ($n_cvc_cc)
+if ($gest_cvc != "SI") $n_cvc_cc = "";
 
 if ($errore != "SI") {
 $cert_cc = risul_query($cert_cc,0,'valpersonalizza');
@@ -840,11 +843,11 @@ esegui_query("update $tablerelclienti set testo2 = '".aggslashdb($val_crypt)."'
 } # fine if ($n_num_cc)
 if ($n_nome_cc) esegui_query("update $tablerelclienti set testo3 = '".aggslashdb($n_nome_cc)."' where idclienti = '$idclienti' and tipo = 'cc' ");
 if ($n_datascadcc) esegui_query("update $tablerelclienti set testo4 = '".aggslashdb($n_datascadcc)."' where idclienti = '$idclienti' and tipo = 'cc' ");
-/*if ($n_cvc_cc) {
+if ($n_cvc_cc) {
 openssl_public_encrypt($n_cvc_cc,$val_crypt,$pub_key);
 $val_crypt = base64_encode($val_crypt);
 esegui_query("update $tablerelclienti set testo5 = '".aggslashdb($val_crypt)."' where idclienti = '$idclienti' and tipo = 'cc' ");
-} # fine if ($n_cvc_cc)*/
+} # fine if ($n_cvc_cc)
 echo ucfirst(mex("i dati della carta di credito sono stati inseriti",$pag));
 } # fine if ($errore != "SI")
 
@@ -907,8 +910,8 @@ if ($d_num_cc) openssl_private_decrypt(base64_decode($d_num_cc),$d_num_cc,$res_p
 $d_nome_cc = risul_query($dati_carta,0,'testo3');
 $d_scad_cc = risul_query($dati_carta,0,'testo4');
 if ($d_scad_cc) $d_scad_cc_f = substr($d_scad_cc,5,2)."-".substr($d_scad_cc,0,4);
-#$d_cvc_cc = risul_query($dati_carta,0,'testo5');
-#if ($d_cvc_cc) openssl_private_decrypt(base64_decode($d_cvc_cc),$d_cvc_cc,$res_pk);
+$d_cvc_cc = risul_query($dati_carta,0,'testo5');
+if ($d_cvc_cc) openssl_private_decrypt(base64_decode($d_cvc_cc),$d_cvc_cc,$res_pk);
 } # fine if (numlin_query($dati_carta))
 $cliente = esegui_query("select * from $tableclienti where idclienti = '$idclienti'");
 if (numlin_query($cliente)) {
@@ -928,18 +931,18 @@ echo ")</h4><br>
 <input type=\"hidden\" name=\"vedi_cc\" value=\"SI\">
 <input type=\"hidden\" name=\"id_transazione\" value=\"$id_transazione\">
 <table cellspacing=0 cellpadding=6>
-<tr style=\"background-color: ".rowbgcolor().";\"><td>".ucfirst(mex("tipo",$pag)).": <b>$d_tipo_cc</b></td>
+<tr style=\"background-color: ".rowbgcolor().";\"><td>".mex("Tipo",$pag).": <b>$d_tipo_cc</b></td>
 <td>".mex("cambia in",$pag).": 
 <input type=\"text\" name=\"n_tipo_cc\" size=\"16\"></td></tr>
-<tr style=\"background-color: ".rowbgcolor().";\"><td>".ucfirst(mex("numero",$pag)).": <b>$d_num_cc</b></td>
+<tr style=\"background-color: ".rowbgcolor().";\"><td>".mex("Numero",$pag).": <b>$d_num_cc</b></td>
 <td>".mex("cambia in",$pag).": 
 <input type=\"text\" name=\"n_num_cc\" size=\"20\"></td></tr>
-<tr style=\"background-color: ".rowbgcolor().";\"><td>".ucfirst(mex("titolare",$pag)).": <b>$d_nome_cc</b></td>
+<tr style=\"background-color: ".rowbgcolor().";\"><td>".mex("Titolare",$pag).": <b>$d_nome_cc</b></td>
 <td>".mex("cambia in",$pag).": 
 <input type=\"text\" name=\"n_nome_cc\" size=\"28\"></td></tr>";
 
-if (date("Ymd",(time() + (C_DIFF_ORE * 3600))) <= str_replace("-","",$d_scad_cc)) echo "<tr style=\"background-color: ".rowbgcolor().";\"><td>".ucfirst(mex("scadenza",$pag)).": <b>$d_scad_cc_f</b></td>";
-else echo "<tr style=\"background-color: ".rowbgcolor().";\"><td>".ucfirst(mex("scadenza",$pag)).": <b class=\"colred\">$d_scad_cc_f</b></td>";
+if (date("Ymd",(time() + (C_DIFF_ORE * 3600))) <= str_replace("-","",$d_scad_cc)) echo "<tr style=\"background-color: ".rowbgcolor().";\"><td>".mex("Scadenza",$pag).": <b>$d_scad_cc_f</b></td>";
+else echo "<tr style=\"background-color: ".rowbgcolor().";\"><td>".mex("Scadenza",$pag).": <b class=\"colred\">$d_scad_cc_f</b></td>";
 echo "<td>".mex("cambia in",$pag).": ";
 $sel_mscadcc = "<select name=\"n_mesescadcc\">
 <option value=\"\" selected>--</option>";
@@ -957,10 +960,12 @@ echo "<option value=\"$num\">$num</option>";
 } # fine for $num1
 echo "</select></td></tr>";
 
-/*echo "<tr style=\"background-color: ".rowbgcolor().";\"><td>".mex("CVC",$pag).": <b>$d_cvc_cc</b></td>
+if ($gest_cvc == "SI") {
+echo "<tr style=\"background-color: ".rowbgcolor().";\"><td>".mex("CVC",$pag).": <b>$d_cvc_cc</b></td>
 <td>".mex("cambia in",$pag).": 
 <input type=\"text\" name=\"n_cvc_cc\" size=\"6\"></td></tr>
-<tr><td style=\"height: 1px;\"></td></tr>";*/
+<tr><td style=\"height: 1px;\"></td></tr>";
+} # fine if ($gest_cvc == "SI")
 
 echo "</table>
 <div style=\"text-align: center;\">
@@ -1334,7 +1339,7 @@ $num = $anno_corr - 12 + $num1;
 echo "<option value=\"$num\">$num</option>";
 } # fine for $num1
 echo "<option value=\"\" selected>--</option>";
-for ($num1 = 0; $num1 < 12; $num1++) {
+for ($num1 = 0; $num1 < 16; $num1++) {
 $num = $anno_corr + $num1;
 echo "<option value=\"$num\">$num</option>";
 } # fine for $num1
