@@ -438,10 +438,11 @@ if ($letto_ca != "n") {
 if ($valore_p_ca and substr($tipo_percentuale,0,7) != "tariffa") { $errore = "SI"; $conflitti .= "3-17;"; }
 if ($moltiplica_ca == "p" or $moltiplica_ca == "t" or $tipo_moltmax == "p" or $tipo_moltmax == "t") { $errore = "SI"; $conflitti .= "11-17;"; }
 } # fine if ($letto_ca != "n")
+if ($escludi_da_tot != "n" and $escludi_da_tot != "s") $errore = "SI";
 if ($limite_ca != "n" and $limite_ca != "s") $errore = "SI";
 if ($limite_ca != "n") {
-if ($tipo_ca == "s" and $associasett != "s" and $numsett_ca != "t") { $errore = "SI"; $conflitti .= "9,10-18;"; }
-if ($tipo_ca == "s" and $associasett != "s" and $periodi_permessi != "tutti" and $tipo_pp == "p") { $errore = "SI"; $conflitti .= "9,13-18;"; }
+if ($tipo_ca == "s" and $associasett != "s" and $numsett_ca != "t") { $errore = "SI"; $conflitti .= "9,10-19;"; }
+if ($tipo_ca == "s" and $associasett != "s" and $periodi_permessi != "tutti" and $tipo_pp == "p") { $errore = "SI"; $conflitti .= "9,13-19;"; }
 if (controlla_num_pos($numlimite_ca) == "NO" or $numlimite_ca == 0) $errore = "SI";
 } # fine if ($limite_ca != "n")
 
@@ -530,13 +531,13 @@ if ($variazione_ca != $dati_ca[$num_costo]['var_percentuale'].$dati_ca[$num_cost
 esegui_query("update $tablenometariffe set variazione_ca = '$variazione_ca' where idntariffe = '$idntariffe'");
 $modificato = "SI";
 } # fine if ($variazione_ca != $dati_ca[$num_costo]['var_percentuale'].$dati_ca[$num_costo]['var_numsett'].$dati_ca[$num_costo]['var_moltiplica'].$dati_ca[$num_costo]['var_periodip'].$dati_ca[$num_costo]['var_tariffea'].$dati_ca[$num_costo]['var_tariffei'].$dati_ca[$num_costo]['var_beniinv'].$dati_ca[$num_costo]['var_appi'].$dati_ca[$num_costo]['var_comb'])
-$mostra_ca = $mostra_ca.$raggruppa_ca.$combina_ca;
-if ($mostra_ca != $dati_ca[$num_costo]['mostra'].$dati_ca[$num_costo]['raggruppa'].$dati_ca[$num_costo]['combina']) {
+$mostra_ca = $mostra_ca.$raggruppa_ca.$combina_ca.$escludi_da_tot;
+if ($mostra_ca != $dati_ca[$num_costo]['mostra'].$dati_ca[$num_costo]['raggruppa'].$dati_ca[$num_costo]['combina'].$dati_ca[$num_costo]['escludi_tot_perc']) {
 esegui_query("update $tablenometariffe set mostra_ca = '$mostra_ca' where idntariffe = '$idntariffe'");
 $modificato = "SI";
-} # fine if ($mostra_ca != $dati_ca[$num_costo]['mostra'].$dati_ca[$num_costo]['raggruppa'].$dati_ca[$num1]['combina'])
+} # fine if ($mostra_ca != $dati_ca[$num_costo]['mostra'].$dati_ca[$num_costo]['raggruppa'].$dati_ca[$num1]['combina'].$dati_ca[$num_costo]['escludi_tot_perc'])
 if ($categoria_ca != $dati_ca[$num_costo]['categoria']) {
-esegui_query("update $tablenometariffe set categoria_ca = '$categoria_ca' where idntariffe = '$idntariffe'");
+esegui_query("update $tablenometariffe set categoria_ca = '".aggslashdb($categoria_ca)."' where idntariffe = '$idntariffe'");
 $modificato = "SI";
 } # fine if ($categoria_ca != $dati_ca[$num_costo]['categoria'])
 if ($letto_ca != $dati_ca[$num_costo]['letto']) {
@@ -665,6 +666,7 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"idntariffe\" value=\"$idntariffe\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
+<input type=\"hidden\" name=\"origine\" value=\"".htmlspecialchars($origine)."\">
 <input class=\"sbutton\" type=\"submit\" name=\"ok\" value=\"OK\"><br>
 </div></form>";
 
@@ -690,6 +692,7 @@ echo "<br><div style=\"text-align: center;\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"idntariffe\" value=\"$idntariffe\">
+<input type=\"hidden\" name=\"origine\" value=\"".htmlspecialchars($origine)."\">
 <input class=\"sbutton\" type=\"submit\" name=\"torna\" value=\"".mex("Torna indietro",$pag)."\">
 <br></div></form></div>";
 } # fine else if ($errore != "SI")
@@ -783,6 +786,7 @@ echo "<br>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"idntariffe\" value=\"$idntariffe\">
+<input type=\"hidden\" name=\"origine\" value=\"".htmlspecialchars($origine)."\">
 <table cellspacing=2 cellpadding=5>
 <tr><td><small>1. </small>".mex("Nome",$pag).": <b>".$dati_ca[$num_costo]['nome']."</b></td>
 <td>".mex("Cambia in",$pag)." <input type=\"text\" name=\"n_nome\" size=\"25\"></td></tr>
@@ -1241,9 +1245,9 @@ echo "</td></tr>";
 echo "</table>
 <input type=\"hidden\" id=\"numcaselle_inv\" name=\"num_beni_inv_elimina_sel\" value=\"$num_beni_inv_elimina_sel\">
 <table>";
-if ($priv_vedi_inv_app != "n" and $priv_mod_beni_in_app != "n") {
 if ($dati_ca[$num_costo]['tipo_beniinv'] == "app") $tipo_bie = "a";
 if ($dati_ca[$num_costo]['tipo_beniinv'] == "mag") $tipo_bie = "m";
+if ($priv_vedi_inv_app != "n" and $priv_mod_beni_in_app != "n") {
 if ($tipo_bie == "a") { $checked = " checked"; $b = "<b>"; $b_slash = "</b>"; }
 else { $checked = ""; $b = ""; $b_slash = ""; }
 if (!$tipo_bie) $checked = " checked";
@@ -1447,8 +1451,17 @@ if ($dati_ca[$num_costo]['letto'] == "s") $selected = " selected";
 else $selected = "";
 echo "<option value=\"s\"$selected>".mex("SI",$pag)."</option>
 </select><br><br>";
+echo "<small>18. </small>".mex("Escludere questo costo dal totale per altri costi percentuali",'creaprezzi.php')."?
+ <select name=\"escludi_da_tot\">";
+if ($dati_ca[$num_costo]['escludi_tot_perc'] == "n") $selected = " selected";
+else $selected = "";
+echo "<option value=\"n\"$selected>".mex("NO",$pag)."</option>";
+if ($dati_ca[$num_costo]['escludi_tot_perc'] == "s") $selected = " selected";
+else $selected = "";
+echo "<option value=\"s\"$selected>".mex("SI",$pag)."</option>
+</select><br><br>";
 echo "<table cellpadding=\"0\" cellspacing=\"0\"><tr><td valign=\"top\">
-<small>18. </small>".mex("Limitarne il numero che è possibile avere contemporaneamente in uno stesso periodo",$pag)."?</td>
+<small>19. </small>".mex("Limitarne il numero che è possibile avere contemporaneamente in uno stesso periodo",$pag)."?</td>
 <td style=\"width: 130px;\">";
 if (!$dati_ca[$num_costo]['numlimite']) $numlimite_ca = "1";
 else $numlimite_ca = $dati_ca[$num_costo]['numlimite'];
@@ -1462,7 +1475,7 @@ echo "<label><input type=\"radio\" id=\"li_s\" name=\"limite_ca\" value=\"s\"$ch
 </td></tr></table></td></tr>";
 
 echo "<tr><td style=\"height: 1px;\"></td></tr><tr><td valign=\"top\">
-<small>19. </small>".mex("Caratteristiche del costo<br> da mantenere quando si<br> modifica una prenotazione",$pag).":</td><td>
+<small>20. </small>".mex("Caratteristiche del costo<br> da mantenere quando si<br> modifica una prenotazione",$pag).":</td><td>
 <table>";
 if ($dati_ca[$num_costo]['var_percentuale'] == "s") { $checked = " checked"; $b = "<b>"; $b_slash = "</b>"; }
 else { $checked = ""; $b = ""; $b_slash = ""; }
@@ -1500,15 +1513,17 @@ if ($dati_ca[$num_costo]['var_comb'] == "s") { $checked = " checked"; $b = "<b>"
 else { $checked = ""; $b = ""; $b_slash = ""; }
 echo "<tr><td><label><input type=\"checkbox\" name=\"mantenere_comb\" value=\"s\"$checked>
 $b".mex("Costi combinati",$pag)."$b_slash</label></td></tr>";
-echo "</table></td></tr>";
+echo "</table></td></tr>
 
-echo "</table>
+</table>";
 
-<br><div style=\"text-align: center;\">
+if ($origine) $action = $origine;
+else $action = "visualizza_tabelle.php#tab_costi_agg";
+echo "<br><div style=\"text-align: center;\">
 <input class=\"sbutton\" id=\"modi\" type=\"submit\" name=\"modifica_costo\" value=\"".mex("Modifica il costo",$pag)."\">
 </div></div></form><br>
 <div style=\"text-align: center;\">
-<form accept-charset=\"utf-8\" method=\"post\" action=\"visualizza_tabelle.php#tab_costi_agg\"><div>
+<form accept-charset=\"utf-8\" method=\"post\" action=\"$action\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"tipo_tabella\" value=\"periodi\">
