@@ -84,9 +84,9 @@ $priv_vedi_tab_prenotazioni = substr($priv_vedi_tab,1,1);
 $contratti_consentiti = risul_query($privilegi_annuali_utente,0,'contratti_consentiti');
 $attiva_contratti_consentiti = substr($contratti_consentiti,0,1);
 if ($attiva_contratti_consentiti == "s") {
-$contratti_consentiti = explode(",",substr($contratti_consentiti,2));
+$contratti_consentiti = explode(",",$contratti_consentiti);
 unset($contratti_consentiti_vett);
-for ($num1 = 0 ; $num1 < count($contratti_consentiti) ; $num1++) if ($contratti_consentiti[$num1]) $contratti_consentiti_vett[$contratti_consentiti[$num1]] = "SI";
+for ($num1 = 1 ; $num1 < count($contratti_consentiti) ; $num1++) if ($contratti_consentiti[$num1]) $contratti_consentiti_vett[$contratti_consentiti[$num1]] = "SI";
 } # fine if ($attiva_contratti_consentiti == "s")
 $priv_mod_prenota = risul_query($privilegi_annuali_utente,0,'priv_mod_prenota');
 $priv_mod_prenotazioni = substr($priv_mod_prenota,0,1);
@@ -607,7 +607,7 @@ $num = $anno_corr - 12 + $num3;
 echo "<option value=\"$num\">$num</option>";
 } # fine for $num3
 echo "<option value=\"\" selected>--</option>";
-for ($num3 = 0 ; $num3 < 12 ; $num3++) {
+for ($num3 = 0 ; $num3 < 16 ; $num3++) {
 $num = $anno_corr + $num3;
 echo "<option value=\"$num\">$num</option>";
 } # fine for $num3
