@@ -82,9 +82,9 @@ $priv_ins_nuove_prenota = substr($priv_ins_prenota,0,1);
 $contratti_consentiti = risul_query($privilegi_annuali_utente,0,'contratti_consentiti');
 $attiva_contratti_consentiti = substr($contratti_consentiti,0,1);
 if ($attiva_contratti_consentiti == "s") {
-$contratti_consentiti = explode(",",substr($contratti_consentiti,2));
+$contratti_consentiti = explode(",",$contratti_consentiti);
 unset($contratti_consentiti_vett);
-for ($num1 = 0 ; $num1 < count($contratti_consentiti) ; $num1++) if ($contratti_consentiti[$num1]) $contratti_consentiti_vett[$contratti_consentiti[$num1]] = "SI";
+for ($num1 = 1 ; $num1 < count($contratti_consentiti) ; $num1++) if ($contratti_consentiti[$num1]) $contratti_consentiti_vett[$contratti_consentiti[$num1]] = "SI";
 } # fine if ($attiva_contratti_consentiti == "s")
 $priv_mod_prenota = risul_query($privilegi_annuali_utente,0,'priv_mod_prenota');
 $priv_mod_prenotazioni = substr($priv_mod_prenota,0,1);
@@ -102,9 +102,9 @@ for ($num1 = 0 ; $num1 < count($costi_agg_consentiti) ; $num1++) if ($costi_agg_
 $contratti_consentiti = risul_query($privilegi_annuali_utente,0,'contratti_consentiti');
 $attiva_contratti_consentiti = substr($contratti_consentiti,0,1);
 if ($attiva_contratti_consentiti == "s") {
-$contratti_consentiti = explode(",",substr($contratti_consentiti,2));
+$contratti_consentiti = explode(",",$contratti_consentiti);
 unset($contratti_consentiti_vett);
-for ($num1 = 0 ; $num1 < count($contratti_consentiti) ; $num1++) if ($contratti_consentiti[$num1]) $contratti_consentiti_vett[$contratti_consentiti[$num1]] = "SI";
+for ($num1 = 1 ; $num1 < count($contratti_consentiti) ; $num1++) if ($contratti_consentiti[$num1]) $contratti_consentiti_vett[$contratti_consentiti[$num1]] = "SI";
 } # fine if ($attiva_contratti_consentiti == "s")
 $priv_ins_costi = risul_query($privilegi_annuali_utente,0,'priv_ins_costi');
 $priv_ins_entrate = substr($priv_ins_costi,1,1);
@@ -161,9 +161,14 @@ $Euro = nome_valuta();
 $stile_soldi = stile_soldi();
 $stile_data = stile_data();
 
+$ordine_inventario = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'ordine_inventario' and idutente = '$id_utente' ");
+$ordine_inventario = risul_query($ordine_inventario,0,'valpersonalizza');
+if ($ordine_inventario == "ins") $ordine_costi = "";
+else $ordine_costi = "nomecostoagg";
+
 
 $dati_tariffe = dati_tariffe($tablenometariffe,"","",$tableregole);
-$dati_ca = dati_costi_agg_ntariffe($tablenometariffe,$dati_tariffe['num'],"NO","",$tableappartamenti);
+$dati_ca = dati_costi_agg_ntariffe($tablenometariffe,$dati_tariffe['num'],"NO",$ordine_costi,$tableappartamenti);
 $id_periodo_corrente = calcola_id_periodo_corrente($anno);
 $attiva_checkin = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'attiva_checkin' and idutente = '$id_utente'");
 $attiva_checkin = risul_query($attiva_checkin,0,'valpersonalizza');
@@ -178,8 +183,8 @@ return $rowbgcolor;
 
 
 if ($inprenota and $id_prenota) {
-$tabelle_lock = array($tablecostiprenota,$tablerelinventario);
-$altre_tab_lock = array($tableprenota,$tableperiodi,$tablecasse);
+$tabelle_lock = array($tableprenota,$tablecostiprenota,$tablerelinventario);
+$altre_tab_lock = array($tableperiodi,$tablecasse);
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 } # fine if ($inprenota and $id_prenota)
 
@@ -230,6 +235,8 @@ $d_nome_tariffa = $d_tariffa[0];
 $d_costo_tariffa = (double) $d_tariffa[1];
 $d_sconto = (double) risul_query($dati_prenota,0,'sconto');
 if (!$d_sconto) $d_sconto = (double) 0;
+$d_costo_tot = (double) risul_query($dati_prenota,0,'tariffa_tot');
+if (!$d_costo_tot) $d_costo_tot = (double) 0;
 $d_caparra = risul_query($dati_prenota,0,'caparra');
 $d_num_persone = risul_query($dati_prenota,0,'num_persone');
 if (!$d_num_persone) $d_num_persone = 0;
@@ -294,7 +301,7 @@ for ($num1 = 0 ; $num1 < $num_costi ; $num1++) if ($num1 != $canc_costo) $id_cos
 $id_costi = substr($id_costi,0,-1);
 } # fine if (strcmp($canc_costo,"") and !$azione)
 
-if ((($moltiplica == 2 or $moltiplica == 10) or ($aggiungi >= 1 and $aggiungi <= 9) or $sottrai == 1) and $id_costi and !$azione) {
+if ((($moltiplica and controlla_num_pos($moltiplica) != "NO") or ($aggiungi and controlla_num_pos($aggiungi) != "NO") or ($sottrai and controlla_num_pos($sottrai) != "NO")) and $id_costi and !$azione) {
 $azione = 1;
 $costi = explode(",",$id_costi);
 $ultimo_costo = $costi[(count($costi) - 1)];
@@ -307,7 +314,10 @@ if ($dati_ca[$num_uc]['moltiplica'] == "c") {
 if (!$molt_ultimo_costo) $molt_ultimo_costo = 1;
 if ($moltiplica) $moltiplica = $molt_ultimo_costo * $moltiplica;
 if ($aggiungi) $moltiplica = $molt_ultimo_costo + $aggiungi;
-if ($sottrai) $moltiplica = $molt_ultimo_costo - $sottrai;
+if ($sottrai) {
+$moltiplica = $molt_ultimo_costo - $sottrai;
+if ($moltiplica < 0) $moltiplica = 0;
+} # fine if ($sottrai)
 if ($moltiplica) {
 if ($id_costi) $id_costi .= ",";
 $id_costi .= $ultimo_costo;
@@ -319,7 +329,7 @@ if ($aggiungi) $moltiplica = $aggiungi + 1;
 for ($num1 = 1 ; $num1 <= $moltiplica ; $num1++) $id_costi .= ",".$ultimo_costo;
 if (substr($id_costi,0,1) == ",") $id_costi = substr($id_costi,1);
 } # fine else if ($dati_ca[$num_uc]['moltiplica'] == "c")
-} # fine if ((($moltiplica == 2 or $moltiplica == 10) or...
+} # fine if ((($moltiplica and controlla_num_pos($moltiplica) != "NO") or ($aggiungi and...
 
 
 
@@ -762,7 +772,7 @@ if ($inprenota and !$errore_prenota and !$azione) {
 $azione = 1;
 if (!$id_prenota) {
 if ($attiva_checkin == "SI") $dati_prenota = esegui_query("select * from $tableprenota where checkin is not NULL and checkout is NULL order by idappartamenti");
-else $dati_prenota = esegui_query("select * from $tableprenota where iddatainizio <= '$id_periodo_corrente' and iddatafine >= '$id_periodo_corrente' order by idappartamenti ");
+else $dati_prenota = esegui_query("select * from $tableprenota where iddatainizio <= '$id_periodo_corrente' and iddatafine >= '".($id_periodo_corrente - 1)."' order by idappartamenti ");
 $num_prenota = numlin_query($dati_prenota);
 $select_prenota = "";
 for ($num1 = 0 ; $num1 < $num_prenota ; $num1++) {
@@ -888,6 +898,9 @@ if (substr($tipo_ca,1,1) != "f") esegui_query("update $tablecostiprenota set val
 if ($dati_ca[$numca]['tasseperc']) esegui_query("update $tablecostiprenota set tasseperc = '".$dati_ca[$numca]['tasseperc']."' where idcostiprenota = '$idcostiprenota'");
 } # fine for $num1
 
+$n_costo_tot = $d_costo_tot + $n_costo_agg_tot - $d_costo_agg_tot;
+esegui_query("update $tableprenota set tariffa_tot = '$n_costo_tot', data_modifica = '$datainserimento' where idprenota = '$id_prenota' ");
+
 $testo_azione = "<br>".mex("I costi sono stati inseriti sulla prenotazione dell'appartamento",'unit.php')." <b>$app_prenota</b>.<br><br>
 <button class=\"pos\" type=\"submit\" style=\"height: 60px; width: 140px; margin: 2px;\"><b>".mex("OK",$pag)."</b></button>";
 $mostra_contr = 1;
@@ -1060,24 +1073,40 @@ echo "</div></form>";
 else {
 
 
-for ($num1 = 2 ; $num1 <= 10 ; $num1 = $num1 + 8) {
-if (!$calcolabile_js['nessuno']) $onclick = " onclick=\"return moltiplica_costi_pv('$num1')\"";
-echo "<div style=\"float: left; padding: 2px;\">
-<button class=\"pos\" type=\"submit\" name=\"moltiplica\" value=\"$num1\"$onclick style=\"height: 60px; width: 64px;\"><b>X $num1</b></button>
+$tasti_pos = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'tasti_pos' and idutente = '$id_utente' ");
+$tasti_pos = risul_query($tasti_pos,0,'valpersonalizza');
+if ($tasti_pos) {
+$tasti_pos = explode(";",$tasti_pos);
+$num_tasti_pos = count($tasti_pos);
+for ($num1 = 0 ; $num1 < $num_tasti_pos ; $num1++) {
+if ($num1 == ($num_tasti_pos - 1)) $stile_float = "clear: right;";
+else $stile_float = "float: left;";
+if ($tasti_pos[$num1] == "s") echo "<div style=\"$stile_float height: 64px; width: 8px;\">&nbsp;</div>";
+else {
+$oper = substr($tasti_pos[$num1],0,1);
+$val_oper = substr($tasti_pos[$num1],1);
+if ($oper == "+") {
+if (!$calcolabile_js['nessuno']) $onclick = " onclick=\"return aggiungi_costi_pv('$val_oper')\"";
+echo "<div style=\"$stile_float\">
+<button class=\"pos\" type=\"submit\" name=\"aggiungi\" value=\"$val_oper\"$onclick style=\"height: 60px; width: 64px; margin: 2px;\"><b>+ $val_oper</b></button>
 </div>";
-} # fine for $num1
-echo "<div style=\"float: left; height: 64px; width: 8px;\">&nbsp;</div>";
-for ($num1 = 1 ; $num1 <= 9 ; $num1++) {
-if (!$calcolabile_js['nessuno']) $onclick = " onclick=\"return aggiungi_costi_pv('$num1')\"";
-echo "<div style=\"float: left;\">
-<button class=\"pos\" type=\"submit\" name=\"aggiungi\" value=\"$num1\"$onclick style=\"height: 60px; width: 64px; margin: 2px;\"><b>+ $num1</b></button>
+} # fine if ($oper == "+")
+if ($oper == "-") {
+if (!$calcolabile_js['nessuno']) $onclick = " onclick=\"return sottrai_costi_pv('$val_oper')\"";
+echo "<div style=\"$stile_float\">
+<button class=\"pos\" type=\"submit\" name=\"sottrai\" value=\"$val_oper\"$onclick style=\"height: 60px; width: 64px; margin: 2px;\"><b>- $val_oper</b></button>
 </div>";
+} # fine if ($oper == "-")
+if ($oper == "x") {
+if (!$calcolabile_js['nessuno']) $onclick = " onclick=\"return moltiplica_costi_pv('$val_oper')\"";
+echo "<div style=\"$stile_float\">
+<button class=\"pos\" type=\"submit\" name=\"moltiplica\" value=\"$val_oper\"$onclick style=\"height: 60px; width: 64px; margin: 2px;\"><b>X $val_oper</b></button>
+</div>";
+} # fine if ($oper == "x")
+} # fine else if ($tasti_pos[$num1] == "s")
 } # fine for $num1
-if (!$calcolabile_js['nessuno']) $onclick = " onclick=\"return sottrai_costi_pv('1')\"";
-echo "<div style=\"float: left; height: 64px; width: 8px;\">&nbsp;</div>
-<div style=\"clear: right;\">
-<button class=\"pos\" type=\"submit\" name=\"sottrai\" value=\"1\"$onclick style=\"height: 60px; width: 64px; margin: 2px;\"><b>- 1</b></button>
-</div><hr style=\"width: 350px; clear: right; margin: 4px auto 4px 0; text-align: left;\">";
+echo "<hr style=\"width: 350px; clear: right; margin: 4px auto 4px 0; text-align: left;\">";
+} # fine if ($tasti_pos)
 
 if (!$calcolabile_js['nessuno']) {
 $vett_calcolabile_js = "";
@@ -1141,7 +1170,7 @@ $onclick_ins_js[$id_costo] = " onclick=\"return ins_cos_pv('$id_costo','$nome_co
 
 $categ = $dati_ca[$num1]['categoria'];
 if (strcmp(trim($categ),"")) {
-if (!$costi_agg_raggr[$categ]) $ultima_categoria = $categ;
+#if (!$costi_agg_raggr[$categ]) $ultima_categoria = $categ;
 $costi_agg_raggr[$categ] .= $id_costo.",";
 } # fine if (strcmp(trim($categ),""))
 else $testo_no_categoria .= "<div style=\"float: left; padding: 2px;\">
@@ -1154,10 +1183,12 @@ if (@is_array($costi_agg_raggr)) {
 if ($testo_no_categoria) echo "<div style=\"float: left; padding: 2px;\">
 <button class=\"pos\" type=\"submit\" name=\"no_categoria\" value=\"1\" onclick=\"return mostra_cat('0');\" style=\"min-height: 60px; min-width: 70px; max-width: 110px;\">".mex("senza categoria",$pag)."</button>
 </div>";
+if ($ordine_inventario != "ins") ksort($costi_agg_raggr);
 reset($costi_agg_raggr);
+$num_categorie = count($costi_agg_raggr);
 $num_cat = 1;
 while (list($categ,$id_costi_cat) = each($costi_agg_raggr)) {
-if ($categ == $ultima_categoria) $float = "clear: right;";
+if ($num_cat == $num_categorie) $float = "clear: right;";
 else $float = "float: left;";
 echo "<div style=\"$float\">
 <button class=\"pos\" type=\"submit\" name=\"n_categoria\" value=\"$categ\" onclick=\"return mostra_cat('$num_cat');\" style=\"min-height: 60px; min-width: 70px; max-width: 110px; margin: 2px;\">$categ</button>
