@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2009 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2015 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -317,7 +317,9 @@ else $stringa_pagine .= "</b>";
 } # fine for $num1
 $stringa_pagine .= "</div>";
 echo $stringa_pagine;
-$stringa_puntini_tab = "<tr><td colspan=\"10\">...</td></tr>";
+$colonne = 10;
+if ($num_tutti_utenti > 1) $colonne++;
+$stringa_puntini_tab = "<tr><td colspan=\"$colonne\">...</td></tr>";
 } # fine if ($num_storia_soldi_prenota > $num_vedi_in_tab)
 else $pagina_prenota = 1;
 } # fine if (!$cerca_prenota)
