@@ -74,6 +74,8 @@ $priv_mod_prenota_ore = substr($priv_mod_prenota,12,3);
 $priv_mod_checkin = substr($priv_mod_prenota,20,1);
 $priv_mod_prenota_comp = substr($priv_mod_prenota,23,1);
 $priv_mod_orig_prenota = substr($priv_mod_prenota,24,1);
+$priv_vedi_commento = substr($priv_mod_prenota,25,1);
+$priv_vedi_commenti_pers = substr($priv_mod_prenota,26,1);
 $priv_vedi_tab = risul_query($privilegi_annuali_utente,0,'priv_vedi_tab');
 $priv_vedi_tab_mesi = substr($priv_vedi_tab,0,1);
 $priv_prenota_gruppi = "NO";
@@ -101,9 +103,9 @@ $priv_oscura_tab_mesi = substr($priv_vedi_tab,8,1);
 $contratti_consentiti = risul_query($privilegi_annuali_utente,0,'contratti_consentiti');
 $attiva_contratti_consentiti = substr($contratti_consentiti,0,1);
 if ($attiva_contratti_consentiti == "s") {
-$contratti_consentiti = explode(",",substr($contratti_consentiti,2));
+$contratti_consentiti = explode(",",$contratti_consentiti);
 unset($contratti_consentiti_vett);
-for ($num1 = 0 ; $num1 < count($contratti_consentiti) ; $num1++) if ($contratti_consentiti[$num1]) $contratti_consentiti_vett[$contratti_consentiti[$num1]] = "SI";
+for ($num1 = 1 ; $num1 < count($contratti_consentiti) ; $num1++) if ($contratti_consentiti[$num1]) $contratti_consentiti_vett[$contratti_consentiti[$num1]] = "SI";
 } # fine if ($attiva_contratti_consentiti == "s")
 $cassa_pagamenti = risul_query($privilegi_annuali_utente,0,'cassa_pagamenti');
 } # fine else if (numlin_query($privilegi_annuali_utente) == 0)
@@ -186,12 +188,17 @@ $priv_mod_prenota_ore = "000";
 $priv_mod_checkin = "s";
 $priv_mod_prenota_comp = "s";
 $priv_mod_orig_prenota = "s";
+$priv_vedi_commento = "s";
+$priv_vedi_commenti_pers = "s";
 $priv_vedi_tab_mesi = "s";
 $attiva_contratti_consentiti = "n";
 $cassa_pagamenti = "";
 } # fine else if ($id_utente != 1)
 if ($anno_utente_attivato == "SI" and $priv_vedi_tab_mesi != "n") {
 
+if ($priv_vedi_commenti_pers = "s") $priv_mod_commenti_pers = "s";
+else $priv_mod_commenti_pers = "n";
+
 if (@is_file(C_DATI_PATH."/dati_subordinazione.php")) {
 $installazione_subordinata = "SI";
 $inserimento_nuovi_clienti = "NO";
@@ -200,6 +207,7 @@ $priv_ins_nuove_prenota = "n";
 $priv_mod_date = "n";
 $priv_mod_assegnazione_app = "n";
 $priv_mod_commento = "n";
+$priv_mod_commenti_pers = "n";
 $priv_mod_sconto = "n";
 $priv_mod_caparra = "n";
 $priv_mod_pagato = "n";
@@ -517,10 +525,10 @@ if ($priv_mod_prenota_iniziate != "s") {
 $id_periodo_corrente = calcola_id_periodo_corrente($anno);
 if ($id_periodo_corrente >= $iddatainizio) $link_modifica = 0;
 } # fine if ($priv_mod_prenota_iniziate != "s")
+$data_ins = risul_query($dati_prn,0,'datainserimento');
 if ($priv_mod_prenota_ore != "000") {
 $adesso = date("YmdHis",(time() + (C_DIFF_ORE * 3600)));
-$data_ins = risul_query($dati_prn,0,'datainserimento');
-$limite = date("YmdHis",mktime((substr($data_ins_js,11,2) + $priv_mod_prenota_ore),substr($data_ins_js,14,2),substr($data_ins_js,17,2),substr($data_ins_js,5,2),substr($data_ins_js,8,2),substr($data_ins_js,0,4)));
+$limite = date("YmdHis",mktime((substr($data_ins,11,2) + $priv_mod_prenota_ore),substr($data_ins,14,2),substr($data_ins,17,2),substr($data_ins,5,2),substr($data_ins,8,2),substr($data_ins,0,4)));
 if ($adesso > $limite) $link_modifica = 0;
 } # fine if ($priv_mod_prenota_ore != "000")
 if ($link_modifica) {
@@ -554,12 +562,18 @@ $tariffa = explode("#@&",$tariffa);
 $tariffa = $tariffa[0];
 $dati_xml .= "\n-".mex("Tipo di tariffa",$pag).": ".str_replace("\"","&quot;",str_replace(">","&gt;",str_replace("<","&lt;",str_replace("&","&amp;",$tariffa))))." ";
 } # fine if ($tariffa)
+$origine = risul_query($dati_prn,0,'origine');
+if ($origine) $dati_xml .= "\n-".mex("Origine",$pag).": ".str_replace("\"","&quot;",str_replace(">","&gt;",str_replace("<","&lt;",str_replace("&","&amp;",$origine))))." ";
+$data_inserimento = formatta_data(substr($data_ins,0,-3),$stile_data);
+$dati_xml .= "\n-".mex("Data inserimento",$pag).": ".str_replace("\"","&quot;",str_replace(">","&gt;",str_replace("<","&lt;",str_replace("&","&amp;",$data_inserimento))))." ";
+if ($priv_vedi_commento == "s") {
 $commento = risul_query($dati_prn,0,'commento');
 if (strstr($commento,">")) {
 $commento = explode(">",$commento);
 $commento = $commento[0];
 } # fine if (strstr($commento,">"))
 if ($commento) $dati_xml .= "\n-".mex("Commento",$pag).": ".str_replace("\"","&quot;",str_replace(">","&gt;",str_replace("<","&lt;",str_replace("&","&amp;",$commento))))." ";
+} # fine if ($priv_vedi_commento == "s")
 $Euro = nome_valuta();
 $stile_soldi = stile_soldi();
 $tariffa_tot = risul_query($dati_prn,0,'tariffa_tot');
@@ -887,7 +901,7 @@ $prenotazione_presente = esegui_query("select
  $tableprenota.datainserimento,
  $tableprenota.utente_inserimento,
  $tableclienti.cognome,
- $tableclienti.utente_inserimento
+ $tableclienti.utente_inserimento as utente_inserimento_cli
  from $tableprenota left outer join $tableclienti on $tableprenota.idclienti = $tableclienti.idclienti where $tableprenota.iddatainizio <= '".($id_data_inizio_tab + $num_colonne - 1)."' and $tableprenota.iddatafine >= '$id_data_inizio_tab'$cond_app_canc$cond_app_perm order by $tableprenota.idappartamenti,$tableprenota.iddatainizio");
 $num_prenotazione_presente = numlin_query($prenotazione_presente);
 $prenota_succ = 0;
@@ -1048,7 +1062,7 @@ if ($id_clienti) {
 $mostra_cliente = "SI";
 if ($vedi_clienti == "NO") $mostra_cliente = "NO";
 if ($vedi_clienti == "PROPRI" or $vedi_clienti == "GRUPPI") {
-$utente_inserimento_cli = risul_query($prenotazione_presente,$prenota_corr,'utente_inserimento',$tableclienti);
+$utente_inserimento_cli = risul_query($prenotazione_presente,$prenota_corr,'utente_inserimento_cli',$tableclienti);
 if ($vedi_clienti == "PROPRI" and $utente_inserimento_cli != $id_utente) $mostra_cliente = "NO";
 if ($vedi_clienti == "GRUPPI" and !$utenti_gruppi[$utente_inserimento_cli]) $mostra_cliente = "NO";
 } # fine if ($vedi_clienti == "PROPRI" or $vedi_clienti == "GRUPPI")
@@ -1249,8 +1263,7 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"visualizza_tabelle
 </div></form>";
 } # fine else if ($mese != $mese_fine_periodi)
 
-if ($lista_prenota_contr) {
-$lista_prenota_contr .= ",";
+if ($lista_prenota_contr) $lista_prenota_contr .= ",";
 $nomi_contratti = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'nomi_contratti' and idutente = '$id_utente'");
 $nomi_contratti = risul_query($nomi_contratti,0,'valpersonalizza');
 $nomi_contratti = explode("#@&",$nomi_contratti);
@@ -1283,7 +1296,6 @@ echo "</td></tr><tr><td style=\"height: 2px;\"></td></tr><tr><td></td><td align=
  <input class=\"sbutton\" type=\"submit\" name=\"vedi_contr\" value=\"".ucfirst(mex("visualizza",$pag))."\">
 </div></form>";
 } # fine if ($option_num_contr and $show_bar != "NO")
-} # fine if ($lista_prenota_contr)
 
 echo "</td></tr><tr><td style=\"height: 12px;\"></td></tr></table>";
 
