@@ -51,9 +51,9 @@ echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\"
 <meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" >
 <title> $titolo </title>";
 if ($pag == "visualizza_contratto.php" and $extra_head) echo $extra_head;
-if (C_NASCONDI_MARCA != "SI") echo "<link rel=\"shortcut icon\" type=\"image/x-icon\" href=\"./img/favicon.ico\">
+if (defined('C_URL_FAVICON') and C_URL_FAVICON != "" and @is_file(C_URL_FAVICON)) echo "<link rel=\"shortcut icon\" type=\"image/x-icon\" href=\"".C_URL_FAVICON."\">
 ";
-elseif (defined('C_URL_FAVICON') and C_URL_FAVICON != "" and @is_file(C_URL_FAVICON)) echo "<link rel=\"shortcut icon\" type=\"image/x-icon\" href=\"".C_URL_FAVICON."\">
+elseif (C_NASCONDI_MARCA != "SI") echo "<link rel=\"shortcut icon\" type=\"image/x-icon\" href=\"./img/favicon.ico\">
 ";
 echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"./base.css$vers_hinc\" media=\"all\">
 <link rel=\"stylesheet\" type=\"text/css\" href=\"./themes/$tema_corr/inc/stylesheet.css$vers_hinc\" media=\"all\">
@@ -101,6 +101,7 @@ if (!$privilegi_globali_utente) $privilegi_globali_utente = esegui_query("select
 if (!$priv_mod_pers) $priv_mod_pers = risul_query($privilegi_globali_utente,0,'priv_mod_pers');
 if (substr($priv_mod_pers,0,1) != "s" and !$modifica_pers) $modifica_pers = "NO";
 if (!$priv_crea_backup) $priv_crea_backup = substr($priv_mod_pers,1,1);
+if (!$priv_crea_interconnessioni) $priv_crea_interconnessioni = substr($priv_mod_pers,3,1);
 if (!$priv_ins_clienti) $priv_ins_clienti = risul_query($privilegi_globali_utente,0,'priv_ins_clienti');
 if (substr($priv_ins_clienti,0,1) != "s" and !$inserimento_nuovi_clienti) $inserimento_nuovi_clienti = "NO";
 if (substr($priv_ins_clienti,1,1) != "s" and substr($priv_ins_clienti,1,1) != "p" and !$modifica_clienti) $modifica_clienti = "NO";
@@ -139,6 +140,7 @@ else {
 if (!$anno_utente_attivato) $anno_utente_attivato = "SI";
 if (!$modifica_pers) $modifica_pers = "SI";
 if (!$priv_crea_backup) $priv_crea_backup = "s";
+if (!$priv_crea_interconnessioni) $priv_crea_interconnessioni = "s";
 if (!$inserimento_nuovi_clienti) $inserimento_nuovi_clienti = "SI";
 if (!$modifica_clienti) $modifica_clienti = "SI";
 if (!$vedi_clienti) $vedi_clienti = "SI";
@@ -259,6 +261,7 @@ echo "</td><td><div class=\"drop\"><div class=\"xldrop\"><ul onmouseover=\"focus
 <li><a href=\"./visualizza_tabelle.php?$sessione_anno_var&amp;tipo_tabella=prenotazioni&amp;sel_tab_prenota=future\">&nbsp;<b>".mex("FUTURE","head.php")."</b>&nbsp;</a></li>
 <li><a href=\"./visualizza_tabelle.php?$sessione_anno_var&amp;tipo_tabella=prenotazioni&amp;sel_tab_prenota=correnti&amp;opz_cerc_pren=arr\">&nbsp;<b>".mex("ARRIVI","head.php")."</b>&nbsp;</a></li>
 <li><a href=\"./visualizza_tabelle.php?$sessione_anno_var&amp;tipo_tabella=prenotazioni&amp;sel_tab_prenota=correnti&amp;opz_cerc_pren=part\">&nbsp;<b>".mex("PARTENZE","head.php")."</b>&nbsp;</a></li>
+<li><a href=\"./visualizza_tabelle.php?$sessione_anno_var&amp;tipo_tabella=prenotazioni&amp;sel_tab_prenota=partcorr\">&nbsp;<b>".mex("PARTENZE E CORRENTI","head.php")."</b>&nbsp;</a></li>
 <li><form accept-charset=\"utf-8\" method=\"post\" action=\"visualizza_tabelle.php\"><div class=\"lifdrop\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
@@ -295,17 +298,15 @@ if (strlen($fr_APPARTAMENTI) > 11) $fr_APPARTAMENTI = substr($fr_APPARTAMENTI,0,
 echo "<a class=\"nav\" href=\"./visualizza_tabelle.php?$sessione_anno_var&amp;tipo_tabella=appartamenti\">&nbsp;<b>$fr_APPARTAMENTI</b>&nbsp;</a></td><td>";
 } # fine if ($priv_vedi_tab_appartamenti != "n")
 } # fine if ($priv_vedi_tab_mesi != "n" or $priv_vedi_tab_prenotazioni != "n" or...
-if ($modifica_pers != "NO" or ($priv_crea_backup == "s" and $installazione_subordinata != "SI")) {
+if ($modifica_pers != "NO" or ($priv_crea_backup == "s" and $installazione_subordinata != "SI") or ($priv_crea_interconnessioni == "s" and C_CREA_SUBORDINAZIONI != "NO")) {
 echo "|</td><td><div class=\"drop\"><ul>
 <li><a class=\"nav\" href=\"./personalizza.php?$sessione_anno_var\">&nbsp;<b>".mex("CONFIGURA","head.php")."</b>&nbsp;</a>";
 echo "<ul>";
-if ($id_utente == 1) {
-if ($installazione_subordinata != "SI") {
+if ($id_utente == 1 and $installazione_subordinata != "SI") {
 echo "<li><a href=\"./gestione_utenti.php?$sessione_anno_var\">&nbsp;<b>".mex("UTENTI","head.php")."</b>&nbsp;</a></li>
 <li><a href=\"./crea_modelli.php?$sessione_anno_var\">&nbsp;<b>".mex("SITO WEB","head.php")."</b>&nbsp;</a></li>";
-} # fine if ($installazione_subordinata != "SI")
-if (C_RESTRIZIONI_DEMO_ADMIN != "SI" and C_CREA_SUBORDINAZIONI != "NO") echo "<li><a href=\"./interconnessioni.php?$sessione_anno_var\">&nbsp;<b>".mex("INTERCONN.","head.php")."</b>&nbsp;</a></li>";
-} # fine if ($id_utente == 1)
+} # fine if ($id_utente == 1 and $installazione_subordinata != "SI")
+if ($priv_crea_interconnessioni == "s" and C_CREA_SUBORDINAZIONI != "NO") echo "<li><a href=\"./interconnessioni.php?$sessione_anno_var\">&nbsp;<b>".mex("INTERCONN.","head.php")."</b>&nbsp;</a></li>";
 if ($priv_crea_backup == "s" and $installazione_subordinata != "SI") echo "<li><a href=\"./crea_backup.php?$sessione_anno_var\">&nbsp;<b>".mex("BACKUP","head.php")."</b>&nbsp;</a></li>";
 if ($modifica_pers != "NO") echo "<li><a href=\"./personalizza.php?$sessione_anno_var#contratti\">&nbsp;<b>".mex("DOCUMENTI","head.php")."</b>&nbsp;</a></li>";
 echo "</ul></li></ul></div></td><td>";
