@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2013 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2014 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -30,6 +30,7 @@ include("./includes/funzioni_$PHPR_DB_TYPE.php");
 $numconnessione = connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT);
 include("./includes/funzioni.php");
 include("./includes/funzioni_contratti.php");
+include("./includes/funzioni_testo.php");
 $tablecontratti = $PHPR_TAB_PRE."contratti";
 $tableprenota = $PHPR_TAB_PRE."prenota".$anno;
 $tablecostiprenota = $PHPR_TAB_PRE."costiprenota".$anno;
@@ -91,10 +92,11 @@ $priv_vedi_telefoni = substr($priv_ins_clienti,3,1);
 $priv_vedi_indirizzo = substr($priv_ins_clienti,4,1);
 $contratti_consentiti = risul_query($privilegi_annuali_utente,0,'contratti_consentiti');
 $attiva_contratti_consentiti = substr($contratti_consentiti,0,1);
+$priv_cancella_contratti = substr($contratti_consentiti,1,1);
 if ($attiva_contratti_consentiti == "s") {
-$contratti_consentiti = explode(",",substr($contratti_consentiti,2));
+$contratti_consentiti = explode(",",$contratti_consentiti);
 unset($contratto_trovato);
-for ($num1 = 0 ; $num1 < count($contratti_consentiti) ; $num1++) if ($contratti_consentiti[$num1] and $contratti_consentiti[$num1] == $numero_contratto) $contratto_trovato = "SI";
+for ($num1 = 1 ; $num1 < count($contratti_consentiti) ; $num1++) if ($contratti_consentiti[$num1] and $contratti_consentiti[$num1] == $numero_contratto) $contratto_trovato = "SI";
 if ($contratto_trovato != "SI") $anno_utente_attivato = "NO";
 } # fine if ($attiva_contratti_consentiti == "s")
 } # fine else if (numlin_query($privilegi_annuali_utente) == 0)
@@ -124,6 +126,7 @@ $vedi_clienti = "SI";
 $priv_vedi_telefoni = "s";
 $priv_vedi_indirizzo = "s";
 $attiva_contratti_consentiti = "n";
+$priv_cancella_contratti = "s";
 } # fine else if ($id_utente != 1)
 if ($anno_utente_attivato == "SI") {
 
@@ -176,15 +179,15 @@ $nome_file_contr = unserialize(risul_query($dati_transazione,0,'dati_transazione
 $tipo_contratto = risul_query($dati_transazione,0,'dati_transazione3');
 $origine = risul_query($dati_transazione,0,'dati_transazione4');
 $origine_vecchia = risul_query($dati_transazione,0,'dati_transazione5');
-if ($cancella == "SI") {
+if ($cancella == "SI" and $priv_cancella_contratti != "n") {
 $mostra_contratto = "NO";
 $mostra_torna_indietro = "SI";
 $num_file_salva = count($nome_file_contr);
 for ($num1 = 1 ; $num1 <= $num_file_salva ; $num1++) {
-unlink($dir_salvato."/".$nome_file_contr[$num1]);
+if (@is_file($dir_salvato."/".$nome_file_contr[$num1])) unlink($dir_salvato."/".$nome_file_contr[$num1]);
 echo "".mex("Il documento",$pag)." <b>".$nome_file_contr[$num1]."</b> ".mex("è stato <b style=\"font-weight: normal; color: blue;\">cancellato</b>",$pag).".<br>";
 } # fine for $num1
-} # fine if ($cancella == "SI")
+} # fine if ($cancella == "SI" and $priv_cancella_contratti != "n")
 } # fine else if ($tipo_transazione != "con_s")
 } # fine elseif ($id_transazione)
 
@@ -332,12 +335,19 @@ if ($mostra_contratto == "SI") {
 
 
 define(C_ID_UTENTE,$id_utente);
+$campi_pers_comm = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'campi_pers_comm' and idutente = '$id_utente'");
+if (numlin_query($campi_pers_comm) == 1) {
+$campi_pers_comm = explode(">",risul_query($campi_pers_comm,0,'valpersonalizza'));
+$num_commenti_pers = count($campi_pers_comm);
+} # fine if (numlin_query($campi_pers_comm) == 1)
+else $num_commenti_pers = 0;
 $campi_pers_cliente = esegui_query("select * from $tablepersonalizza where idpersonalizza = 'campi_pers_cliente' and idutente = '$id_utente' ");
 if (numlin_query($campi_pers_cliente)) {
 $campi_pers_cliente = explode(">",risul_query($campi_pers_cliente,0,'valpersonalizza'));
 $num_campi_pers_cliente = count($campi_pers_cliente);
 } # fine if (numlin_query($campi_pers_cliente))
 else $num_campi_pers_cliente = 0;
+$commento_personalizzato_ = "commento_personalizzato_";
 $campo_personalizzato_ = "campo_personalizzato_";
 include("./includes/variabili_contratto.php");
 
@@ -449,8 +459,14 @@ if (strcmp($sconto,"")) ${"sconto_".$num1} = $sconto;
 if (strcmp(risul_query($dati_prenota,0,'tasseperc'),"")) ${"percentuale_tasse_tariffa_".$num1} = risul_query($dati_prenota,0,'tasseperc');
 if (strcmp(risul_query($dati_prenota,0,'commento'),"")) ${"commento_".$num1} = risul_query($dati_prenota,0,'commento');
 if (strstr(${"commento_".$num1},">")) {
-${"commento_".$num1} = explode(">",${"commento_".$num1});
-${"commento_".$num1} = ${"commento_".$num1}[0];
+$comm = explode(">",${"commento_".$num1});
+${"commento_".$num1} = $comm[0];
+if (strcmp($comm[1],"")) ${"promemoria_entrata_".$num1} = $comm[1];
+if (strcmp($comm[2],"")) ${"promemoria_uscita_".$num1} = $comm[2];
+for ($num2 = 3 ; $num2 < count($comm) ; $num2++) {
+$comm_pers = explode("<",$comm[$num2]);
+if (strcmp($comm_pers[1],"")) ${"commento_personalizzato_".$comm_pers[0]."_".$num1} = $comm_pers[1];
+} # fine for $num2
 } # fine if (strstr(${"commento_".$num1},">"))
 if (strcmp(risul_query($dati_prenota,0,'origine'),"")) ${"origine_prenotazione_".$num1} = risul_query($dati_prenota,0,'origine');
 $caparra = risul_query($dati_prenota,0,'caparra');
@@ -474,6 +490,11 @@ ${"nome_costo_agg".$numca."_".$num1} = $dati_cap[$numca]['nome'];
 ${"val_costo_agg".$numca."_".$num1} = $costo_agg_parziale;
 if (strcmp($dati_cap[$numca]['tasseperc'],"")) ${"percentuale_tasse_costo_agg".$numca."_".$num1} = $dati_cap[$numca]['tasseperc'];
 ${"moltiplica_max_costo_agg".$numca."_".$num1} = $dati_cap[$numca]['moltiplica_costo'];
+if ($dati_cap[$numca]['associasett'] == "s") {
+if ($dati_cap[$numca]['settimane']) ${"giorni_costo_agg".$numca."_".$num1} = $dati_cap[$numca]['settimane'];
+else ${"giorni_costo_agg".$numca."_".$num1} = ",";
+} # fine if ($dati_cap[$numca]['associasett'] == "s")
+else ${"giorni_costo_agg".$numca."_".$num1} = "";
 ${"data_inserimento_costo_agg".$numca."_".$num1} = substr($dati_cap[$numca]['datainserimento'],0,10);
 ${"utente_inserimento_costo_agg".$numca."_".$num1} = $dati_cap[$numca]['utente_inserimento'];
 } # fine for $numca
@@ -641,8 +662,16 @@ header("Content-Disposition: inline; filename=\"$nome_file\"");
 } # fine if ($tipo_contratto == "contrrtf" and !$dir_salva)
 if ($tipo_contratto == "contrtxt" and !$dir_salva) {
 $mostra_headers = "NO";
-if ($nome_file_contr) $nome_file = $nome_file_contr[$n_file];
+if ($nome_file_contr) {
+$nome_file = $nome_file_contr[$n_file];
+if (substr($nome_file,-3) == ".gz") $nome_file = substr($nome_file,0,-3);
+} # fine if ($nome_file_contr)
 else $nome_file = str_replace("\\","_",str_replace("/","_",str_replace(" ","_",$nome_contratto))).".txt";
+$est_txt = esegui_query("select * from $tablecontratti where numero = '$numero_contratto' and tipo = 'est_txt'");
+if (numlin_query($est_txt)) {
+$est_txt = risul_query($est_txt,0,'testo');
+$nome_file = substr($nome_file,0,-4).".$est_txt";
+} # fine if (numlin_query($est_txt))
 header("Pragma: public");
 header("Last-Modified: ".gmdate("D, d M Y H:i:s")." GMT");
 header("Cache-Control: no-store, no-cache, must-revalidate");
